#ifndef lint
static const char yysccsid[] = "@(#)yaccpar	1.9 (Berkeley) 02/21/93";
#endif

#define YYBYACC 1
#define YYMAJOR 1
#define YYMINOR 9
#define YYPATCH 20130925

#define YYEMPTY        (-1)
#define yyclearin      (yychar = YYEMPTY)
#define yyerrok        (yyerrflag = 0)
#define YYRECOVERING() (yyerrflag != 0)

#define YYPREFIX "yy"

#define YYPURE 0

#line 26 "ircd_parser.y"

#define YY_NO_UNPUT
#include <sys/types.h>

#include "stdinc.h"
#include "ircd.h"
#include "tools.h"
#include "list.h"
#include "s_conf.h"
#include "event.h"
#include "s_log.h"
#include "client.h"	/* for UMODE_ALL only */
#include "pcre.h"
#include "irc_string.h"
#include "irc_getaddrinfo.h"
#include "sprintf_irc.h"
#include "memory.h"
#include "modules.h"
#include "s_serv.h" /* for CAP_LL / IsCapable */
#include "s_misc.h" /* for certfp funcs */
#include "hostmask.h"
#include "send.h"
#include "listener.h"
#include "resv.h"
#include "numeric.h"
#include "s_user.h"

#ifdef HAVE_LIBCRYPTO
#include <openssl/rsa.h>
#include <openssl/bio.h>
#include <openssl/pem.h>
#endif

static char *class_name = NULL;
static struct ConfItem *yy_conf = NULL;
static struct AccessItem *yy_aconf = NULL;
static struct MatchItem *yy_match_item = NULL;
static struct ClassItem *yy_class = NULL;
static struct DnsblItem *yy_dconf = NULL;
static char *yy_class_name = NULL;

static dlink_list col_conf_list  = { NULL, NULL, 0 };
static dlink_list hub_conf_list  = { NULL, NULL, 0 };
static dlink_list leaf_conf_list = { NULL, NULL, 0 };
static unsigned int listener_flags = 0;
static unsigned int regex_ban = 0;
static char userbuf[IRCD_BUFSIZE];
static char hostbuf[IRCD_BUFSIZE];
static char reasonbuf[REASONLEN + 1];
static char gecos_name[REALLEN * 4];

extern dlink_list gdeny_items; /* XXX */

static char *resv_reason = NULL;
static char *listener_address = NULL;
static int not_atom = 0;

struct CollectItem {
  dlink_node node;
  char *name;
  char *user;
  char *host;
  char *passwd;
  int  port;
  int  flags;
#ifdef HAVE_LIBCRYPTO
  char *rsa_public_key_file;
  RSA *rsa_public_key;
#endif
};

static void
free_collect_item(struct CollectItem *item)
{
  MyFree(item->name);
  MyFree(item->user);
  MyFree(item->host);
  MyFree(item->passwd);
#ifdef HAVE_LIBCRYPTO
  MyFree(item->rsa_public_key_file);
#endif
  MyFree(item);
}

static void
unhook_hub_leaf_confs(void)
{
  dlink_node *ptr;
  dlink_node *next_ptr;
  struct CollectItem *yy_hconf;
  struct CollectItem *yy_lconf;

  DLINK_FOREACH_SAFE(ptr, next_ptr, hub_conf_list.head)
  {
    yy_hconf = ptr->data;
    dlinkDelete(&yy_hconf->node, &hub_conf_list);
    free_collect_item(yy_hconf);
  }

  DLINK_FOREACH_SAFE(ptr, next_ptr, leaf_conf_list.head)
  {
    yy_lconf = ptr->data;
    dlinkDelete(&yy_lconf->node, &leaf_conf_list);
    free_collect_item(yy_lconf);
  }
}

#line 135 "ircd_parser.y"
#ifdef YYSTYPE
#undef  YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
#endif
#ifndef YYSTYPE_IS_DECLARED
#define YYSTYPE_IS_DECLARED 1
typedef union {
  int number;
  char *string;
} YYSTYPE;
#endif /* !YYSTYPE_IS_DECLARED */
#line 139 "y.tab.c"

/* compatibility with bison */
#ifdef YYPARSE_PARAM
/* compatibility with FreeBSD */
# ifdef YYPARSE_PARAM_TYPE
#  define YYPARSE_DECL() yyparse(YYPARSE_PARAM_TYPE YYPARSE_PARAM)
# else
#  define YYPARSE_DECL() yyparse(void *YYPARSE_PARAM)
# endif
#else
# define YYPARSE_DECL() yyparse(void)
#endif

/* Parameters sent to lex. */
#ifdef YYLEX_PARAM
# define YYLEX_DECL() yylex(void *YYLEX_PARAM)
# define YYLEX yylex(YYLEX_PARAM)
#else
# define YYLEX_DECL() yylex(void)
# define YYLEX yylex()
#endif

/* Parameters sent to yyerror. */
#ifndef YYERROR_DECL
#define YYERROR_DECL() yyerror(const char *s)
#endif
#ifndef YYERROR_CALL
#define YYERROR_CALL(msg) yyerror(msg)
#endif

extern int YYPARSE_DECL();

#define ACCEPT_PASSWORD 257
#define ACTION 258
#define ADMIN 259
#define AFTYPE 260
#define T_ALLOW 261
#define ANTI_NICK_FLOOD 262
#define ANTI_SPAM_EXIT_MESSAGE_TIME 263
#define ANTI_SPAM_CONNECT_NUMERIC 264
#define AUTOCONN 265
#define T_BLOCK 266
#define BURST_AWAY 267
#define BURST_TOPICWHO 268
#define BYTES 269
#define KBYTES 270
#define MBYTES 271
#define GBYTES 272
#define TBYTES 273
#define CALLER_ID_WAIT 274
#define CAN_FLOOD 275
#define CAN_IDLE 276
#define CHANNEL 277
#define CIDR_BITLEN_IPV4 278
#define CIDR_BITLEN_IPV6 279
#define CIPHER_PREFERENCE 280
#define CLASS 281
#define CLIENTCERT_HASH 282
#define CLOAK_KEY1 283
#define CLOAK_KEY2 284
#define CLOAK_KEY3 285
#define CLOAK_WHOIS_ACTUALLY 286
#define ACCOUNT_WHOIS 287
#define COMPRESSED 288
#define COMPRESSION_LEVEL 289
#define CONNECT 290
#define CONNECTFREQ 291
#define CRYPTLINK 292
#define CYCLE_ON_HOSTCHANGE 293
#define DEFAULT_CIPHER_PREFERENCE 294
#define DEFAULT_FLOODCOUNT 295
#define DEFAULT_SPLIT_SERVER_COUNT 296
#define DEFAULT_SPLIT_USER_COUNT 297
#define DENY 298
#define DESCRIPTION 299
#define DIE 300
#define DISABLE_AUTH 301
#define DISABLE_FAKE_CHANNELS 302
#define DISABLE_HIDDEN 303
#define DISABLE_LOCAL_CHANNELS 304
#define DISABLE_REMOTE_COMMANDS 305
#define DNSBL 306
#define DOT_IN_IP6_ADDR 307
#define DOTS_IN_IDENT 308
#define DURATION 309
#define EGDPOOL_PATH 310
#define EMAIL 311
#define ENABLE 312
#define ENCRYPTED 313
#define EXCEED_LIMIT 314
#define EXEMPT 315
#define FAILED_OPER_NOTICE 316
#define FAKENAME 317
#define IRCD_FLAGS 318
#define FLATTEN_LINKS 319
#define FFAILED_OPERLOG 320
#define FKILLLOG 321
#define FKLINELOG 322
#define FGLINELOG 323
#define FIOERRLOG 324
#define FOPERLOG 325
#define FOPERSPYLOG 326
#define FUSERLOG 327
#define GECOS 328
#define GENERAL 329
#define GLINE 330
#define GLINES 331
#define GLINE_EXEMPT 332
#define GLINE_LOG 333
#define GLINE_TIME 334
#define GLINE_MIN_CIDR 335
#define GLINE_MIN_CIDR6 336
#define GLOBAL_KILL 337
#define IRCD_AUTH 338
#define NEED_IDENT 339
#define HAVENT_READ_CONF 340
#define HIDDEN 341
#define HIDDEN_ADMIN 342
#define HIDDEN_NAME 343
#define HIDDEN_OPER 344
#define HIDE_SERVER_IPS 345
#define HIDE_SERVERS 346
#define HIDE_SPOOF_IPS 347
#define HOST 348
#define HUB 349
#define HUB_MASK 350
#define IDLETIME 351
#define IGNORE_BOGUS_TS 352
#define INVISIBLE_ON_CONNECT 353
#define IP 354
#define KILL 355
#define KILL_CHASE_TIME_LIMIT 356
#define KLINE 357
#define KLINE_EXEMPT 358
#define KLINE_REASON 359
#define KLINE_WITH_REASON 360
#define KNOCK_DELAY 361
#define KNOCK_DELAY_CHANNEL 362
#define LAZYLINK 363
#define LEAF_MASK 364
#define LINKS_DELAY 365
#define LISTEN 366
#define T_LOG 367
#define LOGGING 368
#define LOG_LEVEL 369
#define MAX_ACCEPT 370
#define MAX_BANS 371
#define MAX_CHANS_PER_USER 372
#define MAX_GLOBAL 373
#define MAX_IDENT 374
#define MAX_LOCAL 375
#define MAX_NICK_CHANGES 376
#define MAX_NICK_TIME 377
#define MAX_NUMBER 378
#define MAX_TARGETS 379
#define MESSAGE_LOCALE 380
#define MIN_NONWILDCARD 381
#define MIN_NONWILDCARD_SIMPLE 382
#define MODULE 383
#define MODULES 384
#define NAME 385
#define NEED_PASSWORD 386
#define IS_WEBIRC 387
#define NETWORK_DESC 388
#define NETWORK_NAME 389
#define NICK 390
#define NICK_CHANGES 391
#define NICK_COLLIDE_REALHOST 392
#define NO_CREATE_ON_SPLIT 393
#define NO_JOIN_ON_SPLIT 394
#define NO_OPER_FLOOD 395
#define NO_TILDE 396
#define NOT 397
#define NUMBER 398
#define NUMBER_PER_IDENT 399
#define NUMBER_PER_CIDR 400
#define NUMBER_PER_IP 401
#define NUMBER_PER_IP_GLOBAL 402
#define OPERATOR 403
#define OPERS_BYPASS_CALLERID 404
#define OPER_LOG 405
#define OPER_ONLY_UMODES 406
#define OPER_PASS_RESV 407
#define OPER_SPY_T 408
#define OPER_FARCONNECT 409
#define OPER_UMODES 410
#define JOIN_FLOOD_COUNT 411
#define JOIN_FLOOD_TIME 412
#define PACE_WAIT 413
#define PACE_WAIT_SIMPLE 414
#define PASSWORD 415
#define PATH 416
#define PING_COOKIE 417
#define PING_TIME 418
#define PING_WARNING 419
#define PORT 420
#define QSTRING 421
#define QUIET_ON_BAN 422
#define REASON 423
#define REDIRPORT 424
#define REDIRSERV 425
#define REGEX_T 426
#define REHASH 427
#define TREJECT_HOLD_TIME 428
#define REMOTE 429
#define REMOTEBAN 430
#define RESTRICT_CHANNELS 431
#define RESTRICTED 432
#define RSA_PRIVATE_KEY_FILE 433
#define RSA_PUBLIC_KEY_FILE 434
#define RSA_CRYPTLINK_KEY_FILE 435
#define SSL_CERTIFICATE_FILE 436
#define SSL_DH_PARAM_FILE 437
#define RESV 438
#define RESV_EXEMPT 439
#define SECONDS 440
#define MINUTES 441
#define HOURS 442
#define DAYS 443
#define WEEKS 444
#define SENDQ 445
#define SEND_PASSWORD 446
#define SERVERHIDE 447
#define SERVERINFO 448
#define SERVICES 449
#define SERVICES_NAME 450
#define SERVLINK_PATH 451
#define IRCD_SID 452
#define TKLINE_EXPIRE_NOTICES 453
#define T_SHARED 454
#define T_CLUSTER 455
#define TYPE 456
#define SHORT_MOTD 457
#define SILENT 458
#define SPOOF 459
#define SPOOF_NOTICE 460
#define STATS_E_DISABLED 461
#define STATS_I_OPER_ONLY 462
#define STATS_K_OPER_ONLY 463
#define STATS_O_OPER_ONLY 464
#define STATS_P_OPER_ONLY 465
#define TBOOL 466
#define TMASKED 467
#define T_REJECT 468
#define TS_MAX_DELTA 469
#define TS_WARN_DELTA 470
#define TWODOTS 471
#define T_ALL 472
#define T_BOTS 473
#define T_SOFTCALLERID 474
#define T_CALLERID 475
#define T_CCONN 476
#define T_NOCTCP 477
#define T_CLIENT_FLOOD 478
#define T_DEAF 479
#define T_DEBUG 480
#define T_DRONE 481
#define T_EXTERNAL 482
#define T_FULL 483
#define T_HIDECHANNELS 484
#define T_FARCONNECT 485
#define T_INVISIBLE 486
#define T_IPV4 487
#define T_IPV6 488
#define T_LOCOPS 489
#define T_LOGPATH 490
#define T_L_CRIT 491
#define T_L_DEBUG 492
#define T_L_ERROR 493
#define T_L_INFO 494
#define T_L_NOTICE 495
#define T_L_TRACE 496
#define T_L_WARN 497
#define T_MAX_CLIENTS 498
#define T_NCHANGE 499
#define T_OPERWALL 500
#define T_REJ 501
#define T_SERVNOTICE 502
#define T_SKILL 503
#define T_SPY 504
#define T_SSL 505
#define T_UMODES 506
#define T_UNAUTH 507
#define T_UNRESV 508
#define T_UNXLINE 509
#define T_WALLOP 510
#define THROTTLE_TIME 511
#define THROTTLE_NUM 512
#define TOPICBURST 513
#define TRUE_NO_OPER_FLOOD 514
#define TKLINE 515
#define TXLINE 516
#define TRESV 517
#define UNKLINE 518
#define USER 519
#define USE_EGD 520
#define USE_EXCEPT 521
#define USE_INVEX 522
#define HIDE_KILLER 523
#define USE_REGEX_BANS 524
#define USE_KNOCK 525
#define USE_NOCTCP 526
#define USE_LOGGING 527
#define USE_WHOIS_ACTUALLY 528
#define VHOST 529
#define VHOST6 530
#define XLINE 531
#define WARN 532
#define WARN_NO_NLINE 533
#define YYERRCODE 256
static const short yylhs[] = {                           -1,
    0,    0,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
    5,    5,    5,    5,    5,    2,    2,    1,    1,    1,
    1,    1,    1,    4,    4,    3,    3,    3,    3,   25,
   27,   27,   28,   28,   28,   29,   30,   31,   26,   32,
   32,   33,   33,   33,   33,   34,   35,   36,   13,   37,
   37,   38,   38,   38,   38,   38,   38,   38,   38,   38,
   38,   38,   38,   38,   38,   50,   51,   46,   47,   39,
   49,   42,   43,   44,   40,   48,   45,   41,    6,   52,
   52,   53,   53,   53,   53,   54,   56,   55,    7,   57,
   57,   58,   58,   58,   58,   58,   58,   58,   58,   58,
   58,   58,   58,   58,   59,   60,   63,   70,   64,   68,
   65,   66,   69,   67,   61,   61,   61,   61,   61,   61,
   61,   62,   72,    8,   71,   71,   73,   73,   75,   75,
   75,   75,   75,   75,   75,   75,   75,   75,   75,   75,
   75,   75,   75,   75,   75,   75,   75,   75,   75,   75,
   75,   75,   75,   76,   74,   77,   97,   78,   95,   96,
   82,  100,   81,  101,  101,  102,  102,  102,  102,  102,
  102,  102,  102,  102,  102,  102,  102,  102,  102,  102,
  102,  102,  102,  102,  102,  102,   83,   84,   90,   85,
   86,   87,   88,   89,   91,   92,   93,   79,   80,   98,
   94,  103,   99,  104,  104,  107,  105,  108,  105,  106,
  106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
  106,  106,  106,  106,  106,  106,  110,   10,  109,  109,
  111,  111,  113,  113,  113,  113,  113,  113,  113,  113,
  113,  113,  113,  113,  113,  113,  114,  112,  117,  118,
  120,  121,  122,  123,  124,  125,  126,  115,  116,  119,
  127,   11,  130,  129,  131,  131,  132,  132,  128,  128,
  133,  133,  133,  133,  133,  138,  134,  137,  137,  139,
  139,  135,  136,  140,   12,  141,  141,  142,  142,  142,
  142,  142,  142,  142,  142,  142,  142,  142,  142,  142,
  142,  142,  142,  142,  142,  142,  143,  144,  160,  153,
  145,  159,  161,  146,  162,  162,  165,  163,  166,  163,
  164,  164,  164,  164,  164,  164,  164,  164,  164,  164,
  164,  147,  148,  149,  157,  150,  151,  152,  155,  156,
  154,  158,  167,   15,  168,  168,  169,  169,  169,  169,
  170,  171,  172,  173,   16,  174,  174,  175,  175,  175,
  175,  176,  177,  179,  178,  180,  180,  181,  181,  181,
  181,  181,  181,  181,  181,  181,  181,  181,  181,  181,
  182,   17,  183,  183,  184,  184,  184,  185,  187,  186,
  188,  188,  189,  189,  189,  189,  189,  189,  189,  189,
  189,  189,  189,  191,   18,  190,  190,  192,  192,  194,
  194,  194,  194,  194,  194,  194,  194,  194,  194,  194,
  194,  194,  194,  194,  194,  194,  194,  194,  194,  195,
  193,  196,  197,  198,  199,  201,  200,  200,  202,  214,
  203,  215,  215,  218,  216,  219,  216,  217,  217,  217,
  217,  217,  217,  211,  208,  210,  209,  207,  213,  204,
  205,  206,  212,  220,   19,  223,  222,  224,  224,  225,
  221,  221,  226,  226,  226,  226,  227,  228,  229,   20,
  230,  230,  231,  231,  231,  232,  233,   21,  234,  234,
  235,  235,  235,  236,  237,  238,   24,  241,  240,  242,
  242,  243,  239,  239,  244,  244,  244,  244,  245,  246,
   22,  247,  247,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  248,
  248,  248,  248,  248,  248,  248,  248,  248,  248,  302,
  303,  300,  304,  313,  305,  301,  260,  249,  250,  289,
  251,  252,  253,  254,  255,  256,  257,  258,  259,  296,
  261,  262,  307,  308,  309,  310,  311,  312,  263,  264,
  291,  266,  271,  306,  267,  267,  269,  269,  268,  283,
  284,  270,  272,  273,  274,  275,  277,  276,  265,  279,
  288,  290,  292,  280,  281,  298,  299,  294,  295,  314,
  282,  315,  315,  316,  316,  316,  316,  316,  316,  316,
  316,  316,  316,  316,  316,  316,  316,  316,  316,  316,
  316,  316,  316,  316,  317,  278,  318,  318,  319,  319,
  319,  319,  319,  319,  319,  319,  319,  319,  319,  319,
  319,  319,  319,  319,  319,  319,  319,  319,  319,  286,
  287,  285,  293,  297,  320,   23,  321,  321,  322,  322,
  322,  322,  322,  322,  322,  323,  324,  329,  325,  330,
  330,  331,  331,  326,  327,  332,  328,  333,  333,  334,
  334,    9,  335,  335,  336,  336,  336,  336,  336,  336,
  336,  336,  336,  336,  336,  336,  336,  336,  336,  336,
  336,  336,  336,  336,  336,  336,  357,  356,  351,  337,
  338,  339,  342,  340,  341,  344,  345,  346,  347,  343,
  348,  349,  350,  352,  353,  354,  355,   14,  358,  358,
  359,  359,  359,  359,  359,  359,  359,  359,  360,  361,
  365,  362,  364,  363,  366,
};
static const short yylen[] = {                            2,
    0,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    2,    0,    1,    2,    3,    3,
    3,    3,    3,    0,    1,    2,    3,    3,    3,    5,
    2,    1,    1,    1,    2,    4,    4,    0,    6,    2,
    1,    1,    1,    1,    2,    4,    4,    4,    5,    2,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    2,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    5,    2,
    1,    1,    1,    1,    2,    4,    4,    4,    5,    2,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    2,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    0,    7,    0,    1,    2,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    2,    4,    1,    4,    4,    4,    4,    4,
    4,    0,    5,    3,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    0,    5,    3,    1,    0,    3,    0,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    0,    7,    0,    1,
    2,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    2,    4,    1,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    0,    6,    0,    5,    3,    1,    1,    1,    2,    1,
    1,    1,    1,    1,    2,    0,    5,    3,    1,    1,
    3,    4,    4,    0,    6,    2,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    2,    4,    4,    4,    4,
    4,    4,    0,    5,    3,    1,    0,    3,    0,    2,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    0,    6,    2,    1,    1,    1,    1,    2,
    4,    4,    4,    0,    6,    2,    1,    1,    1,    1,
    2,    4,    4,    0,    5,    3,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    0,    6,    2,    1,    1,    1,    2,    4,    0,    5,
    3,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    0,    7,    0,    1,    2,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    2,    4,
    1,    4,    4,    4,    4,    4,    4,    4,    4,    0,
    5,    3,    1,    0,    3,    0,    2,    1,    1,    1,
    1,    1,    1,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    0,    6,    0,    5,    3,    1,    1,
    2,    1,    1,    1,    1,    1,    4,    4,    0,    6,
    2,    1,    1,    1,    1,    4,    4,    5,    2,    1,
    1,    1,    1,    4,    4,    0,    6,    0,    5,    3,
    1,    1,    2,    1,    1,    1,    1,    1,    4,    4,
    5,    2,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    0,
    5,    3,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    0,    5,    3,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    4,
    4,    4,    4,    4,    0,    6,    2,    1,    1,    1,
    1,    1,    1,    1,    1,    4,    4,    0,    5,    3,
    1,    1,    1,    4,    4,    0,    5,    3,    1,    1,
    1,    5,    2,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
    1,    1,    1,    1,    1,    1,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    4,    4,    4,
    4,    4,    4,    4,    4,    4,    4,    5,    2,    1,
    1,    1,    1,    1,    1,    1,    1,    1,    4,    4,
    4,    4,    4,    4,    4,
};
static const short yydefred[] = {                         1,
    0,    0,    0,    0,  237,  414,  489,   48,    0,  506,
    0,  705,  294,  474,  271,    0,    0,  133,  353,    0,
    0,  364,  391,    2,    3,    4,    5,    6,    7,    8,
    9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
   19,   20,   21,   22,   23,   24,   25,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,   91,   92,   93,   94,  756,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  734,  735,  736,  737,  738,  739,  740,  741,  742,  743,
  744,  745,  746,  747,  748,  749,  750,  751,  752,  753,
  754,  755,  258,    0,  240,  441,    0,  417,    0,    0,
  503,    0,    0,    0,  500,  501,  502,    0,  589,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  675,    0,
  650,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  523,  524,  525,  526,  527,
  528,  529,  530,  531,  532,  533,  534,  535,  536,  537,
  538,  539,  540,  541,  542,  543,  544,  545,  546,  547,
  548,  549,  550,  551,  552,  553,  554,  555,  556,  557,
  558,  559,  560,  561,  562,  563,  564,  565,  566,  567,
  568,  569,  570,  571,  572,  573,  574,  575,  576,  577,
  578,  579,  580,  581,  582,  583,  584,  585,  586,  587,
  588,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  101,
  102,  103,  104,  105,  106,  107,  108,  109,  110,  111,
  112,  113,    0,    0,    0,    0,   42,   43,   44,  165,
    0,  136,    0,  788,    0,    0,    0,    0,    0,    0,
    0,    0,  780,  781,  782,  783,  784,  785,  786,  787,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   61,   62,   63,   64,   65,
   66,   67,   68,   69,   70,   71,   72,   73,   74,    0,
    0,   95,    0,    0,    0,    0,   90,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  733,
    0,    0,  495,    0,    0,    0,  492,  493,  494,    0,
    0,    0,    0,    0,   51,   52,   53,   54,    0,    0,
    0,  499,  518,    0,    0,  508,    0,  517,  514,  515,
  516,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,  522,  715,  726,
    0,    0,  718,    0,    0,    0,  708,  709,  710,  711,
  712,  713,  714,    0,    0,    0,    0,    0,    0,  323,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  297,  298,  299,  300,  301,  302,  303,
  304,  305,  306,  307,  308,  309,  310,  311,  312,  313,
  314,  315,  486,    0,  476,    0,    0,  485,  482,  483,
  484,    0,  273,    0,    0,    0,    0,  282,  280,  281,
  283,  284,  114,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  100,   45,    0,    0,
    0,   41,    0,    0,    0,    0,    0,    0,  356,  357,
  358,  359,    0,    0,    0,    0,    0,    0,    0,    0,
  779,   75,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   60,    0,    0,  374,
    0,    0,  367,  368,  369,  370,    0,    0,  399,    0,
  394,  395,  396,    0,    0,    0,   89,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  732,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  242,  243,  244,  245,  246,
  247,  248,  249,  250,  251,  252,  253,  254,  255,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  450,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  419,  420,  421,  422,  423,  424,  425,  426,  427,  428,
  429,  430,  431,  432,  433,  434,  435,  436,  437,  438,
    0,    0,    0,  491,   55,    0,    0,    0,    0,   50,
    0,    0,  498,    0,    0,    0,    0,  513,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  521,    0,    0,    0,
    0,    0,    0,    0,  707,  316,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  296,    0,    0,    0,    0,
  481,  285,    0,    0,    0,    0,    0,  279,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   99,    0,    0,   40,
    0,    0,    0,    0,    0,    0,  212,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  172,    0,    0,    0,    0,  138,  139,  140,  141,
  142,  143,  144,  145,  146,  147,  148,  149,  150,  151,
  152,  153,  154,  155,  156,  157,  158,  159,  160,  161,
  162,  360,    0,    0,    0,    0,  355,    0,    0,    0,
    0,    0,    0,    0,  778,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   59,  371,
    0,    0,    0,    0,  366,  397,    0,    0,    0,  393,
   98,   97,   96,  775,  757,  772,  771,  758,  760,    0,
    0,    0,    0,    0,   27,   28,  766,  767,  770,  768,
  773,  774,  776,  777,  769,  759,  761,  762,  763,  764,
  765,  256,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  241,  439,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  418,    0,
    0,  490,    0,    0,    0,   49,  505,  504,    0,    0,
    0,  507,  602,  606,  607,  592,  630,  613,  614,  615,
  616,  617,  643,  642,  702,  647,  600,  704,  639,  645,
  601,  590,  591,  610,  598,  638,  599,  619,  597,  612,
  611,  605,  604,  603,  640,  637,  700,  701,  594,  634,
  631,  679,  695,  696,  680,  681,  682,  683,  690,  684,
  698,  699,  693,  697,  686,  691,  687,  692,  685,  689,
  688,  694,    0,  678,  636,  654,  670,  671,  655,  656,
  657,  658,  665,  659,  673,  674,  668,  672,  661,  666,
  662,  667,  660,  664,  663,  669,    0,  653,  629,  632,
  646,  595,  618,  641,  596,  633,  621,  627,  628,  625,
  626,  622,  623,  609,  608,    0,    0,    0,   35,   36,
  703,  649,  648,  635,  644,  624,  593,  620,    0,    0,
    0,    0,    0,    0,  706,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  295,    0,    0,    0,  475,    0,    0,
    0,    0,    0,  289,  272,  118,  124,  122,  121,  123,
  119,  120,  117,  125,  131,  126,  130,  128,  129,  127,
  116,  115,  132,   46,   47,  163,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  137,    0,    0,    0,  354,  794,  789,  793,  791,
  795,  790,  792,   82,   88,   80,   84,   83,   78,   79,
   76,   77,   81,   87,   85,   86,    0,    0,    0,  365,
    0,    0,  392,   29,   30,   31,   32,   33,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  238,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  415,  496,  497,   57,   56,   58,  519,  520,
  512,    0,  511,  676,    0,  651,    0,   37,   38,   39,
  731,  730,    0,  729,  717,  716,  723,  722,    0,  721,
  725,  724,  345,  321,  319,  322,  344,  327,    0,  326,
    0,  347,  343,  342,  352,  351,  346,  318,  350,  349,
  348,  320,  317,  488,  480,    0,  479,  487,  278,  277,
    0,  276,  293,  292,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  134,  362,  363,  361,  372,  378,  389,  384,  388,
  390,  387,  386,  383,  379,  382,  385,  380,  381,    0,
  377,  373,  398,  403,  409,  413,  412,  411,  408,  404,
  407,  410,  405,  406,    0,  402,  268,  269,  262,  264,
  266,  265,  263,  257,  270,  261,  259,  260,  267,  445,
  447,  448,  468,  473,  472,  467,  466,  465,  449,  454,
    0,  453,    0,  442,  470,  471,  440,  446,  464,  444,
  469,  443,  509,    0,  677,  652,  727,    0,  719,    0,
    0,  324,    0,  335,  336,  332,  338,  334,  333,  341,
  340,  337,  339,  331,  330,  477,    0,  274,    0,  291,
  288,  287,  207,  171,  167,  205,  169,  216,    0,  215,
    0,  203,  197,  208,  209,  200,  164,  204,  210,  168,
  206,  198,  199,  170,  211,  176,  192,  193,  177,  178,
  179,  180,  187,  181,  195,  196,  190,  194,  183,  188,
  184,  189,  182,  186,  185,  191,    0,  175,  202,  166,
  201,  375,    0,  400,    0,    0,  451,    0,  461,  462,
  459,  460,  458,  463,  457,  510,  728,  720,  328,  325,
  478,  275,    0,  213,    0,  228,  226,  235,  225,  220,
  229,  233,  222,  230,  232,  236,  227,  221,  234,  231,
  223,  224,  219,  173,    0,  376,  401,  455,  452,  217,
  214,  174,
};
static const short yydgoto[] = {                          1,
  985,  986, 1159, 1160,   24,   25,   26,   27,   28,   29,
   30,   31,   32,   33,   34,   35,   36,   37,   38,   39,
   40,   41,   42,   43,   44,   45,  306,  307,  308,  309,
   53,  404,  405,  406,  407,  408,  345,  346,  347,  348,
  349,  350,  351,  352,  353,  354,  355,  356,  357,  358,
  359,   73,   74,   75,   76,   77,  289,  290,  291,  292,
  293,  294,  295,  296,  297,  298,  299,  300,  301,  302,
  311,   63,  906,  312,  907,  908,  909,  910,  911,  912,
  913,  914,  915,  916,  917,  918,  919,  920,  921,  922,
  923,  924,  925,  926,  927,  928,  929,  930,  931, 1247,
 1557, 1558, 1232, 1519, 1520, 1603, 1583, 1521,  124,   50,
  675,  125,  676,  677,  678,  679,  680,  681,  682,  683,
  684,  685,  686,  687,  688,  689,   60,  557,  558,  853,
 1381, 1382,  559,  560,  561,  562, 1203, 1387, 1204,   58,
  523,  524,  525,  526,  527,  528,  529,  530,  531,  532,
  533,  534,  535,  536,  537,  538,  539,  540,  541,  542,
  832, 1359, 1360, 1505, 1491, 1361,   64,  588,  589,  590,
  591,  592,   67,  622,  623,  624,  625,  626,  962, 1430,
 1431,   68,  630,  631,  632,  633,  968, 1445, 1446,  127,
   51,  710,  128,  711,  712,  713,  714,  715,  716,  717,
  718,  719,  720,  721,  722,  723,  724,  725,  726,  727,
  728,  729,  730, 1028, 1471, 1472, 1575, 1566, 1473,   59,
  547,  548,  848, 1376, 1377,  549,  550,  551,   52,  396,
  397,  398,  399,  134,  135,  136,  137,   55,  417,  418,
  746, 1332, 1333,  419,  420,  421,  205,  206,  207,  208,
  209,  210,  211,  212,  213,  214,  215,  216,  217,  218,
  219,  220,  221,  222,  223,  224,  225,  226,  227,  228,
  229,  230,  231,  232,  233,  234,  235,  236,  237,  238,
  239,  240,  241,  242,  243,  244,  245,  246,  247,  248,
  249,  250,  251,  252,  253,  254,  255,  256,  257,  258,
  259,  260,  261,  262,  263,  264,  265,  266,  267,  268,
  269,  270,  271,  463, 1137, 1138,  461, 1113, 1114,   57,
  496,  497,  498,  499,  500,  501,  502,  503,  821, 1349,
 1350,  818, 1343, 1344,  100,  101,  102,  103,  104,  105,
  106,  107,  108,  109,  110,  111,  112,  113,  114,  115,
  116,  117,  118,  119,  120,  121,  122,  322,  323,  324,
  325,  326,  327,  328,  329,  330,
};
static const short yysindex[] = {                         0,
  866,  -44,  -90,  -86,    0,    0,    0,    0,  -83,    0,
  -70,    0,    0,    0,    0,  -61,  -59,    0,    0,  -57,
  -55,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -234,  738, -351,
 -339,  -39,  -31, -243,  -27,  459,   -9,    1,   15,   22,
  693, -225, -262,   44, -236,  352,   55,   74,  124,  139,
  141,  146, -107,    0,    0,    0,    0,    0,  151,  159,
  160,  163,  166,  167,  168,  173,  183,  184,  186,  187,
  189,  190,  192,  196,  202,  203,  219,  220,  221,  172,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  100,    0,    0,  110,    0, -242, -215,
    0,  227,  233, -100,    0,    0,    0, -187,    0,  238,
  240,  241,  249,  252,  256,  258,  259,  262,  263,  264,
  265,  267,  270,  272,  273,  274,  277,  289,  293,  300,
  303,  304,  306,  307,  309,  310,  313,  316,  317,  319,
  321,  322,  323,  325,  326,  327,  328,  334,    0,  337,
    0,  348,  350,  353,  358,  359,  361,  362,  366,  369,
  370,  380,  381,  383,  385,  386,  387,  388,  389,  390,
  393,  394,  395,  398, -121,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, -224,  788, -246, -221,  181,  400,  401,  402,  406,
  410,  411,  412,  414,  417,  418,  420,  429,  162,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  333,  430,  431, -116,    0,    0,    0,    0,
  198,    0, -230,    0,  432,  433,  434,  437,  438,  439,
  441,   60,    0,    0,    0,    0,    0,    0,    0,    0,
  448,  447,  449,  450,  451,  452,  453,  456,  457,  468,
  469,  471,  476,  478,  -77,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, -214,
 -213,    0,  -69,  125,  127,  486,    0,   83,   85,  157,
  158,   92,   93,  165,  165,  170,  174,   94,   95,  177,
  165,  105,  111,  115,  119,  120,  123,  129,  517,    0,
  179,  331,    0,  529,  532, -117,    0,    0,    0,  541,
  540,  543,  544, -108,    0,    0,    0,    0,  185,  188,
  548,    0,    0,  549,  552,    0, -119,    0,    0,    0,
    0,  136,  165,  148,  149,  165,  195,  199,  200,  156,
  161,  228,  204,  230,  164,  169,  171,  234,  212,  175,
  236,  244,  245,  191,  165,  193,  194,  255,  215,  197,
  257,  269,  165,  275,  217,  276,  279,  205,  206,  214,
  556,  216,  589,  165,  165,  222,  165,  237,  247,  224,
  239,  242, -391, -380,  246,  248,  165,  165,  280,  165,
  285,  251,  261,  266,  268,  281,  595,    0,    0,    0,
  600,  601,    0,  609,  625, -106,    0,    0,    0,    0,
    0,    0,    0,  628,  638,  639,  641,  642,  643,    0,
  645,  646,  650,  652,  657,  663,  668,  669,  670,  674,
  677,  678,  260,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  688,    0,  689, -109,    0,    0,    0,
    0,  666,    0,  691,  694,  695, -102,    0,    0,    0,
    0,    0,    0,  336,  338,  340,  341,  342,  347,  349,
  351,   29,  355,  357,  292,  712,    0,    0,  360,  363,
  714,    0,  561,  715,  719,  721,  722, -120,    0,    0,
    0,    0,  320,  324,  330,  371,  332,  335,  165,  732,
    0,    0,  372,  339,  376,  379,  382,  392,  403,  404,
  405,  407,  409,  413,  416,  743,    0,  749,  748,    0,
  753,  -87,    0,    0,    0,    0,  757,  760,    0, -101,
    0,    0,    0,  763,  764,  768,    0,  771,  772,  773,
  774,  786,  787, -342,  789,  790,  793,  794,  796,  797,
  798,  799,  800,  803,  805,  808,  809,  811,  812,    0,
  816,  817,  819,  822,  823,  824,  825,  827,  828,  829,
  831,  832,  833,  834,  291,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  818,
  835,  836,  838,  839,  840,  841,  843,  845,  846,    0,
  847,  850,  852,  853,  854,  856,  858,  864,  869,  116,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  426,  506,  872,    0,    0,  165,  511,  512,  875,    0,
  876,  877,    0,  520,  521,  882,  885,    0,  886,  888,
  889,  891,  892,  894,  895,  896,  897,  898,  900,  901,
  902,  903,  904,  906,  907,  909,  913,  915,  916,  918,
  922,  924,  925,  926,  927,  930,  934,  939,  941,  942,
  943,  946,  948,  949,  951,  962,  964,  826,  966,  867,
  967,  968,  969,  971,  973,  974,  978,  979,  980,  986,
  987,  988,  989,  990,  993,  994,  995, -210,  996,  998,
 1000, 1006, 1007, 1009, 1012, 1013,    0, 1016,  165,  472,
 1017,  653,  660, 1014,    0,    0,  498,  661,  662,  618,
  619, 1025,  621,  622,  623,  627,  629,  647,  683,  713,
  684,  696,  648,  697, 1032,    0,  698, 1051,  700, 1056,
    0,    0, 1055,  702,  709,  735, 1075,    0, 1076, 1077,
 1078, 1079, 1080, 1081, 1082, 1083, 1085, 1089, 1092, 1093,
 1094, 1098, 1099, 1100, 1102, 1103,    0, 1104, 1106,    0,
 1107, 1109, 1110, 1112, 1115, 1116,    0, 1117, 1119, 1121,
 1125, 1126, 1127, 1128, 1129, 1130, 1131, 1139, 1140, 1141,
 1144,    0, 1145, 1146, 1147,    9,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  747,  806,  807, 1150,    0, 1151, 1155, 1160,
 1167, 1170, 1172, 1174,    0, 1176, 1177, 1180, 1181, 1182,
 1183, 1184, 1185, 1186, 1187, 1190, 1192, 1193,    0,    0,
  837, 1194,  849, 1195,    0,    0,  851, 1196, 1197,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,  165,
  165,  165,  165,  165,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  855,  863,  165,  870,  873,  878,  880,  859,
  881,  883,  165,  165,  280, 1208,    0,    0,  861, -270,
  820,  862,  868,  821,  830,  857,  871, 1212,  874,  910,
  911,  914,  887,  917,  933,  893,  936, 1215,    0, 1218,
 1225,    0, 1229, 1231, 1232,    0,    0,    0, 1234, 1235,
  302,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  -23,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,   13,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  280,  280,  280,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, -263, 1238,
 1239, -255, 1257, 1258,    0, 1260, 1263, 1265, 1275, 1278,
  958, 1286, 1289, 1299, 1301, 1302, 1303, 1304, 1305, 1306,
 1313, 1314, 1316,    0, 1317,  957, 1327,    0, -329, 1333,
 1334,  928, 1351,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  931,  975,  977,  935,
  937, 1339,  944,  945,  947,  950,  952,  981,  953,  954,
 1001,  955,  959,  960, 1002,  961, 1353,  963, 1003,  965,
 1358,    0, 1369, 1371, 1373,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0, 1374,  -12, 1375,    0,
 1376,  707,    0,    0,    0,    0,    0,    0, 1377, 1378,
 1379, 1380, 1381, 1382, 1383, 1384, 1385, 1386, 1387, 1388,
 1389,    0, 1390, 1391, 1392, 1393, 1394, 1395, 1396, 1397,
 1398, 1399, 1062, 1401, 1402, 1403, 1404, 1405, 1406, 1407,
 1408, 1409,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   14,    0,    0,  826,    0,  867,    0,    0,    0,
    0,    0,   19,    0,    0,    0,    0,    0,   30,    0,
    0,    0,    0,    0,    0,    0,    0,    0,   36,    0,
  664,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,   64,    0,    0,    0,    0,
   69,    0,    0,    0, 1071,  735, 1411, 1412, 1413, 1414,
 1415, 1416, 1084, 1417, 1418, 1419, 1420, 1421, 1423, 1424,
 1425, 1426, 1427, 1428, 1429, 1430, 1431,  905, 1432, 1433,
 1434,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,   71,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,   72,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
   73,    0, -238,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,  302,    0,    0,    0, -263,    0, -255,
  664,    0,  958,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  957,    0, -329,    0,
    0,    0,    0,    0,    0,    0,    0,    0,  131,    0,
  667,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,  150,    0,    0,    0,
    0,    0,  -12,    0,  707, -238,    0, 1062,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  667,    0, 1084,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  905,    0,    0,    0,    0,    0,
    0,    0,
};
static const short yyrindex[] = {                         0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1372,
 1400,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1410,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0, 1435,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1437,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0, 1435,
 1435, 1435, 1435, 1435,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0, 1437, 1437, 1437,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
  879,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,  152, 1438,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, -237,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  699,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,  879,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, -237,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  699,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,
};
static const short yygindex[] = {                         0,
 -374, -862, -477,-1112,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0, 1198,    0,    0,
    0,    0, 1095,    0,    0,    0,    0, 1153,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0, 1436,    0,    0,    0,    0, 1211,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,  596,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0, -104,    0,    0,  -82,  -78,    0,    0,    0,    0,
    0,    0,  842,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,   -3,  956,    0,    0,    0,    0,    0,  121,    0,
    0,  985,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,   17,   20,    0,    0,    0,    0,  932,    0,
    0,    0,    0,    0,  890,    0,    0,    0,    0,    0,
  -49,    0,    0,  899,    0,    0,    0,    0,  -50,    0,
    0,    0,    0,  814,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  -52,  -48,    0,    0,    0,
    0,    0,    0,    0,   12,  983,    0,    0,    0,    0,
 1132,    0,    0,    0, 1422,    0,    0,    0,    0,    0,
    0,    0,   37, 1105,    0,    0,    0, 1320,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  201,    0,    0,  207,    0,
    0, 1030,    0,    0,    0,    0,    0,    0,    0,    0,
   41,    0,    0,   39,    0, 1439,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,    0,    0,    0, 1210,    0,
    0,    0,    0,    0,    0,    0,
};
#define YYTABLESIZE 1556
static const short yytable[] = {                        645,
  646,  809, 1341,  487,  936,  747,  652,  733,  581,  543,
 1347, 1379,  131,  393,   46,  850,  739,  366,  824,  314,
 1335,   69,  857,  969,  411,  584, 1569,  456, 1570,  456,
  303,  489,   48,  490,  552, 1334,   49,  964,  132,   54,
  400,  618,  627, 1338, 1339, 1340,  585,  616,  750, 1571,
  456,  753,   56, 1572,  456,  644, 1337, 1484, 1156, 1157,
 1158,   61, 1488,   62,   70,   65,  315,   66,  413,  123,
  772, 1336, 1483, 1490,  800,  801,   71, 1487,  780, 1493,
   47,  126,  316,  129,  491,  802,  803,  492, 1489,  791,
  792,  130,  794,  401, 1492,  138,  553,  980,  981,  982,
  983,  984,  806,  807,  317,  810,  318, 1507,  319,  320,
  133,  394, 1509,  272, 1563, 1565, 1568, 1284, 1285, 1286,
 1287, 1288, 1506,  273, 1573,  456,  554, 1508,  321, 1562,
 1564, 1567,  555, 1251,  139,  584,  413,  274,  393,  303,
  140,  141,  142,  493,  275,  143,  543,  400,   69,  489,
   72,  490,  144,  552,  627,  131,  585,  304,  310,  586,
  494,  145,  146,  147,  148,  149,  313,  150,  618,  402,
  619,  628,  151,  152, 1585, 1380,  544,  360,  331,  153,
  395,  132,  362,  154,  600,  155,  156,  808,  157, 1584,
  305,   70,  587, 1605,  158,  290,  361,  414,  556,  363,
  401,  364,  491,   71, 1342,  492,  365,  403, 1604,  545,
  290,  368, 1348,  159,  160,  553, 1304, 1305,  161,  369,
  370,  332,  391,  371,  944,  162,  372,  373,  374,  163,
  164,  165,  392,  375,  166,  415,  394,  167,  168,  563,
 1038,  620,  629,  376,  377,  554,  378,  379,  169,  380,
  381,  555,  382,  133,  170,  171,  383,  172,  173,  174,
  175,  493,  384,  385,  881,  414,  304,  882,  416,  586,
  176,  333,  546,  177, 1574,  456,  402,   72,  494,  386,
  387,  388,  178,  628,  179,  180,  576,  409,  181,  883,
  884,  182,  183,  410,  495,  184,  389,  619,  422,  305,
  423,  424,  587,  415,  621,  395,  185,  334,  885,  425,
  335,  336,  426,  544,  403,  314,  427,  556,  428,  429,
  583,  886,  430,  431,  432,  433,  887,  434,  186,  187,
  435,  188,  436,  437,  438,  189,  416,  439,  888,  190,
  191,  192,  193,  194, 1417,  889,  545,  195,  196,  440,
  890,  634,  891,  441,  629,  337,  197,  338,  339,  340,
  442, 1043,  315,  443,  444,  892,  445,  446,  620,  447,
  448,  690,  691,  449,  341,  692,  450,  451,  316,  452,
  693,  453,  454,  455,  845,  456,  457,  458,  459,  198,
  199,  578,  200,  893,  460,  694,  695,  462,  201,  894,
  317,  202,  318,  696,  319,  320,  203,  697,  464,  546,
  465,  204,  495,  466, 1418, 1016,  895,  276,  467,  468,
  342,  469,  470,  896,  321, 1419,  471,   78,  698,  472,
  473,  621,  699,  700,  661,  897, 1420,  898,  899,   79,
  474,  475,  900,  476, 1170,  477,  478,  479,  480,  481,
  482,  343,  344,  483,  484,  485,  662,  663,  486, 1421,
  564,  565,  566,  701,   80,  702,  567,   81,   82,  664,
  568,  569,  570,   83,  571,   84, 1422,  572,  573,  703,
  574,  277,  278,  279,  280,  281,  282,  283,  284,  575,
  579,  580,  593,  594,  595, 1423, 1424,  596,  597,  598,
  704,  599, 1425, 1426, 1427, 1428,  602,  603,  901,  604,
  605,  606,  607,  608,  902,  504,  609,  610, 1429,  867,
  868,  869,  870,  871,  872,  873,  903,  904,  611,  612,
  285,  613,   85,   86,  505,  705,  614, 1301,  615,  905,
  506,  507,   87,   88,  637,  635,  661,  636,  638,  706,
  639,  665,  666,  667,  640,  641,  668,  642,  643,  649,
  650,  707,  644,  669,   89,   90,  286,  647,  662,  663,
  653,  648,  508,  509,  651,  660,  654,  510,  670,  671,
  655,  664,   91,   92,  656,  657,  690,  691,  658,  731,
  692,  511,  732,   93,  659,  693,  672,  673,  512,  735,
  736,  749,   94,  737,  738,  741,  743,  331,  742,  744,
  694,  695,  745,  751,  752,  754,  788,  513,  696,  755,
  756,  757,  697,  674,  760,  759,  758,  761,  708,  762,
 1291,  765,  766,  768,  763,  776,  764,  782, 1299, 1300,
  767,  769,  770,  698,  709,  514,  515,  699,  700,  790,
  332,  287,  775,  817,  778,  516,  771,  795,  773,  774,
  819,  820,  777,  665,  666,  667,  779,  796,  668,  822,
  785,  786,  781,  783,  517,  669,  784,  808,  701,  787,
  702,  789,  811,  518,  519,  823,  826,  793,  288,  797,
  670,  671,   95,   96,  703,   97,   98,   99,  827,  828,
  333,  829,  830,  831,  798,  833,  834,  799,  672,  673,
  835,  804,  836,  805,  139,  704,  812,  837,  520,  521,
  140,  141,  142,  838,  852,  143,  813, 1331,  839,  840,
  841,  814,  144,  815,  842,  674,  334,  843,  844,  335,
  336,  145,  146,  147,  148,  149,  816,  150,  847,  849,
  705,  854,  151,  152,  855,  856,  859,  876,  860,  153,
  861,  862,  863,  154,  706,  155,  156,  864,  157,  865,
  877,  866,  880,  932,  158,  874,  707,  875,  522,  933,
  878,  934,  935,  879,  337,  938,  338,  339,  340,  939,
  945,  941,  946,  159,  160,  940,  948,  942,  161,  949,
  943,  959,  950,  341,  947,  162,  956,  960,  961,  163,
  164,  165,  951,  963,  166,  966,  881,  167,  168,  882,
  967,  971,  972,  952,  953,  954,  973,  955,  169,  974,
  975,  976,  977,  957,  170,  171,  958,  172,  173,  174,
  175,  883,  884,  708,  978,  979, 1040,  987,  988,  342,
  176,  989,  990,  177,  991,  992,  993,  994,  995,  709,
  885,  996,  178,  997,  179,  180,  998,  999,  181, 1000,
 1001,  182,  183,  886, 1002,  184, 1018, 1003,  887, 1004,
  343,  344, 1005, 1006, 1007, 1008,  185, 1009, 1010, 1011,
  888, 1012, 1013, 1014, 1015, 1019, 1020,  889, 1021, 1022,
 1023, 1024,  890, 1025,  891, 1026, 1027, 1029,  186,  187,
 1030,  188, 1031, 1032, 1033,  189, 1034,  892, 1035,  190,
  191,  192,  193,  194, 1036, 1586, 1041,  195,  196, 1037,
 1042, 1044, 1045, 1046, 1047, 1048,  197, 1171, 1494, 1495,
 1049, 1050, 1051, 1052, 1053,  893, 1054, 1055,  276, 1056,
 1057,  894, 1058, 1059, 1060, 1061, 1062,  218, 1063, 1064,
 1065, 1066, 1067, 1176, 1068, 1069, 1587, 1070,  895,  198,
  199, 1071,  200, 1072, 1073,  896, 1074, 1496,  201, 1588,
 1075,  202, 1076, 1077, 1078, 1079,  203,  897, 1080,  898,
  899,  204, 1081,   78,  900, 1497, 1589, 1082,  218, 1083,
 1084, 1085, 1498, 1590, 1086,   79, 1087, 1088, 1591, 1089,
 1592,  218,  277,  278,  279,  280,  281,  282,  283,  284,
 1090, 1499, 1091, 1593, 1115, 1139, 1140, 1141,  218, 1142,
   80, 1143, 1144,   81,   82,  218, 1145, 1146, 1147,   83,
  218,   84,  218,  504, 1148, 1149, 1150, 1151, 1152, 1500,
 1501, 1153, 1154, 1155, 1161,  218, 1162, 1594, 1163, 1502,
  901,  285,  505, 1434, 1164, 1165,  902, 1166,  506,  507,
 1167, 1168, 1175, 1173, 1595, 1596, 1169, 1172,  903,  904,
 1174, 1177, 1178, 1179, 1180, 1181, 1182, 1183, 1184,  218,
 1194,  905, 1185, 1597, 1186, 1598, 1599,  286,   85,   86,
  508,  509, 1503, 1188, 1190,  510,  218,  218,   87,   88,
 1189, 1196, 1187, 1192, 1198, 1199, 1191, 1193, 1195,  511,
 1197,    2, 1200, 1504,    3,  218,  512,  218,  218, 1201,
   89,   90, 1202, 1205, 1206, 1207, 1208, 1209, 1210, 1211,
 1212, 1213,    4, 1214, 1435,  513,    5, 1215,   91,   92,
 1216, 1217, 1218,  329,  329,    6, 1219, 1220, 1221,   93,
 1222, 1223, 1224,    7, 1225, 1226, 1600, 1253,   94, 1227,
 1228,    8, 1229,  514,  515, 1230, 1231, 1233, 1436, 1234,
    9, 1235,  287,  516, 1601, 1236, 1237, 1238, 1239, 1240,
 1241, 1242,  329,   10,   11, 1437,   12, 1602,  218, 1243,
 1244, 1245,  517,   13, 1246, 1248, 1249, 1250, 1256, 1257,
  329,  518,  519, 1258, 1438, 1439,  218,  329, 1259,  288,
   14, 1440, 1441, 1442, 1443, 1260, 1254, 1255, 1261,  218,
 1262,   15, 1263,   16, 1264, 1265,  329, 1444, 1266, 1267,
 1268, 1269, 1270, 1271, 1272, 1273,  520,  521, 1274,   17,
 1275, 1276, 1289, 1280, 1278, 1283, 1282, 1277,   95,   96,
 1290,   97,   98,   99,  329,  329, 1302, 1292,   18, 1279,
 1293, 1281, 1313, 1323,  329, 1294, 1324, 1295, 1297, 1296,
 1298, 1303, 1307, 1325, 1318, 1306, 1309, 1326, 1308, 1327,
 1328, 1312, 1329, 1330, 1314, 1310, 1345, 1346, 1092, 1093,
 1094, 1095, 1096,   19, 1097, 1098,  522, 1099, 1100, 1101,
 1102, 1103,   20,   21, 1104, 1351, 1352,  329, 1353,   22,
   23, 1354, 1311, 1355, 1105, 1106, 1107, 1108, 1109, 1110,
 1315, 1316, 1111, 1356, 1317, 1112, 1357, 1319,  329, 1116,
 1117, 1118, 1119, 1120, 1362, 1121, 1122, 1363, 1123, 1124,
 1125, 1126, 1127, 1320, 1358, 1128, 1322, 1364, 1321, 1365,
 1366, 1367, 1368, 1369, 1370, 1129, 1130, 1131, 1132, 1133,
 1134, 1371, 1372, 1135, 1373, 1374, 1136, 1536, 1537, 1538,
 1539, 1540, 1375, 1541, 1542, 1378, 1543, 1544, 1545, 1546,
 1547, 1383, 1384, 1548, 1386, 1389, 1388, 1390, 1385, 1393,
 1391, 1399, 1392, 1549, 1550, 1551, 1552, 1553, 1554, 1394,
 1395, 1555, 1396, 1408, 1556, 1397, 1412, 1398, 1400, 1401,
 1403, 1402, 1406, 1410, 1404, 1405, 1407, 1413, 1409, 1414,
 1411, 1415, 1416, 1432, 1433, 1447, 1448, 1449, 1450, 1451,
 1452, 1453, 1454, 1455, 1456, 1457, 1458, 1459, 1460, 1461,
 1462, 1463, 1464, 1465, 1466, 1467, 1468, 1469, 1470, 1474,
 1475, 1476, 1477, 1478, 1479, 1480, 1481, 1482, 1510, 1512,
 1513, 1514, 1515, 1516, 1517, 1522, 1523, 1524, 1525, 1526,
 1518, 1527, 1528, 1529, 1530, 1531, 1532, 1533, 1534, 1535,
 1559, 1560, 1561,   26,  239,   34,  286,  617,  740,  577,
 1612, 1252, 1611,  582, 1610, 1582, 1511,  846,  367, 1580,
 1579,  965,  858, 1606, 1607, 1609, 1017, 1608, 1581,  937,
 1576,  748,  416, 1039,  488,  825, 1577,  734,  970,  851,
 1578,  601,  135,    0,    0,    0,    0, 1486,  390,    0,
    0, 1485,    0,    0,    0,    0,    0,    0,    0,    0,
    0,    0,    0,    0,    0,  412,
};
static const short yycheck[] = {                        374,
  375,  479,  266,  125,  125,  125,  381,  125,  125,  256,
  266,  341,  256,  256,   59,  125,  125,  125,  125,  256,
   44,  256,  125,  125,  125,  256,  265,  265,  267,  267,
  256,  256,  123,  258,  256,   59,  123,  125,  282,  123,
  256,  256,  256, 1156, 1157, 1158,  277,  125,  423,  288,
  288,  426,  123,  292,  292,  398,   44,   44,  269,  270,
  271,  123,   44,  123,  299,  123,  303,  123,  256,  421,
  445,   59,   59,   44,  466,  467,  311,   59,  453,   44,
  125,  421,  319,  123,  309,  466,  467,  312,   59,  464,
  465,  123,  467,  309,   59,  123,  318,  440,  441,  442,
  443,  444,  477,  478,  341,  480,  343,   44,  345,  346,
  354,  354,   44,  123,   44,   44,   44,  980,  981,  982,
  983,  984,   59,  123,  363,  363,  348,   59,  365,   59,
   59,   59,  354,  125,  256,  256,  256,  123,  256,  256,
  262,  263,  264,  368,  123,  267,  256,  256,  256,  256,
  385,  258,  274,  256,  256,  256,  277,  383,  421,  390,
  385,  283,  284,  285,  286,  287,  123,  289,  256,  385,
  385,  385,  294,  295,   44,  505,  423,  123,  256,  301,
  423,  282,   59,  305,  125,  307,  308,  398,  310,   59,
  416,  299,  423,   44,  316,   44,  123,  385,  420,   61,
  309,   61,  309,  311,  468,  312,   61,  423,   59,  456,
   59,   61,  468,  335,  336,  318,  487,  488,  340,   61,
   61,  299,  123,   61,  599,  347,   61,   61,   61,  351,
  352,  353,  123,   61,  356,  423,  354,  359,  360,   59,
  125,  456,  456,   61,   61,  348,   61,   61,  370,   61,
   61,  354,   61,  354,  376,  377,   61,  379,  380,  381,
  382,  368,   61,   61,  256,  385,  383,  259,  456,  390,
  392,  349,  519,  395,  513,  513,  385,  385,  385,   61,
   61,   61,  404,  385,  406,  407,  125,   61,  410,  281,
  282,  413,  414,   61,  519,  417,  125,  385,   61,  416,
   61,   61,  423,  423,  519,  423,  428,  385,  300,   61,
  388,  389,   61,  423,  423,  256,   61,  420,   61,   61,
  123,  313,   61,   61,   61,   61,  318,   61,  450,  451,
   61,  453,   61,   61,   61,  457,  456,   61,  330,  461,
  462,  463,  464,  465,  357,  337,  456,  469,  470,   61,
  342,  421,  344,   61,  456,  433,  478,  435,  436,  437,
   61,  736,  303,   61,   61,  357,   61,   61,  456,   61,
   61,  256,  257,   61,  452,  260,   61,   61,  319,   61,
  265,   61,   61,   61,  125,   61,   61,   61,   61,  511,
  512,   59,  514,  385,   61,  280,  281,   61,  520,  391,
  341,  523,  343,  288,  345,  346,  528,  292,   61,  519,
   61,  533,  519,   61,  427,  125,  408,  256,   61,   61,
  498,   61,   61,  415,  365,  438,   61,  256,  313,   61,
   61,  519,  317,  318,  256,  427,  449,  429,  430,  268,
   61,   61,  434,   61,  819,   61,   61,   61,   61,   61,
   61,  529,  530,   61,   61,   61,  278,  279,   61,  472,
   61,   61,   61,  348,  293,  350,   61,  296,  297,  291,
   61,   61,   61,  302,   61,  304,  489,   61,   61,  364,
   61,  320,  321,  322,  323,  324,  325,  326,  327,   61,
   61,   61,   61,   61,   61,  508,  509,   61,   61,   61,
  385,   61,  515,  516,  517,  518,   59,   61,  500,   61,
   61,   61,   61,   61,  506,  256,   61,   61,  531,  491,
  492,  493,  494,  495,  496,  497,  518,  519,   61,   61,
  369,   61,  361,  362,  275,  420,   61, 1015,   61,  531,
  281,  282,  371,  372,   59,  421,  256,  421,  466,  434,
  466,  373,  374,  375,  398,  398,  378,  466,  466,  466,
  466,  446,  398,  385,  393,  394,  405,  398,  278,  279,
  466,  398,  313,  314,  398,   59,  466,  318,  400,  401,
  466,  291,  411,  412,  466,  466,  256,  257,  466,   61,
  260,  332,   61,  422,  466,  265,  418,  419,  339,   59,
   61,  466,  431,   61,   61,  421,   59,  256,  421,   61,
  280,  281,   61,  466,  466,  421,   61,  358,  288,  421,
  421,  466,  292,  445,  421,  398,  466,  398,  513,  466,
 1005,  398,  421,  398,  466,  421,  466,  421, 1013, 1014,
  466,  398,  398,  313,  529,  386,  387,  317,  318,   61,
  299,  490,  398,   59,  398,  396,  466,  421,  466,  466,
   61,   61,  466,  373,  374,  375,  398,  421,  378,   61,
  466,  466,  398,  398,  415,  385,  398,  398,  348,  466,
  350,  466,  398,  424,  425,   61,   59,  466,  527,  466,
  400,  401,  521,  522,  364,  524,  525,  526,   61,   61,
  349,   61,   61,   61,  466,   61,   61,  466,  418,  419,
   61,  466,   61,  466,  256,  385,  466,   61,  459,  460,
  262,  263,  264,   61,   59,  267,  466,  426,   61,   61,
   61,  466,  274,  466,   61,  445,  385,   61,   61,  388,
  389,  283,  284,  285,  286,  287,  466,  289,   61,   61,
  420,   61,  294,  295,   61,   61,  421,  466,  421,  301,
  421,  421,  421,  305,  434,  307,  308,  421,  310,  421,
   59,  421,   59,   59,  316,  421,  446,  421,  519,   61,
  421,   61,   61,  421,  433,  466,  435,  436,  437,  466,
   59,  421,  421,  335,  336,  466,  421,  466,  340,  421,
  466,   59,  421,  452,  466,  347,  398,   59,   61,  351,
  352,  353,  421,   61,  356,   59,  256,  359,  360,  259,
   61,   59,   59,  421,  421,  421,   59,  421,  370,   59,
   59,   59,   59,  421,  376,  377,  421,  379,  380,  381,
  382,  281,  282,  513,   59,   59,  421,   59,   59,  498,
  392,   59,   59,  395,   59,   59,   59,   59,   59,  529,
  300,   59,  404,   59,  406,  407,   59,   59,  410,   59,
   59,  413,  414,  313,   59,  417,   59,   61,  318,   61,
  529,  530,   61,   61,   61,   61,  428,   61,   61,   61,
  330,   61,   61,   61,   61,   61,   61,  337,   61,   61,
   61,   61,  342,   61,  344,   61,   61,   61,  450,  451,
   61,  453,   61,   61,   61,  457,   61,  357,   61,  461,
  462,  463,  464,  465,   61,  259,  421,  469,  470,   61,
   59,  421,  421,   59,   59,   59,  478,  466,  275,  276,
  421,  421,   61,   59,   59,  385,   59,   59,  256,   59,
   59,  391,   59,   59,   59,   59,   59,  259,   59,   59,
   59,   59,   59,  466,   59,   59,  300,   59,  408,  511,
  512,   59,  514,   59,   59,  415,   59,  314,  520,  313,
   59,  523,   59,   59,   59,   59,  528,  427,   59,  429,
  430,  533,   59,  256,  434,  332,  330,   59,  300,   59,
   59,   59,  339,  337,   59,  268,   59,   59,  342,   59,
  344,  313,  320,  321,  322,  323,  324,  325,  326,  327,
   59,  358,   59,  357,   59,   59,   59,   59,  330,   59,
  293,   59,   59,  296,  297,  337,   59,   59,   59,  302,
  342,  304,  344,  256,   59,   59,   59,   59,   59,  386,
  387,   59,   59,   59,   59,  357,   59,  391,   59,  396,
  500,  369,  275,  357,   59,   59,  506,   59,  281,  282,
   59,   59,   59,  421,  408,  409,   61,   61,  518,  519,
  421,  421,  421,  466,  466,   61,  466,  466,  466,  391,
   59,  531,  466,  427,  466,  429,  430,  405,  361,  362,
  313,  314,  439,  421,  421,  318,  408,  409,  371,  372,
  398,   61,  466,  466,   59,   61,  421,  421,  421,  332,
  421,  256,  421,  460,  259,  427,  339,  429,  430,  421,
  393,  394,  398,   59,   59,   59,   59,   59,   59,   59,
   59,   59,  277,   59,  438,  358,  281,   59,  411,  412,
   59,   59,   59,  275,  276,  290,   59,   59,   59,  422,
   59,   59,   59,  298,   59,   59,  500,  421,  431,   61,
   61,  306,   61,  386,  387,   61,   61,   61,  472,   61,
  315,   61,  490,  396,  518,   61,   61,   61,   61,   61,
   61,   61,  314,  328,  329,  489,  331,  531,  500,   61,
   61,   61,  415,  338,   61,   61,   61,   61,   59,   59,
  332,  424,  425,   59,  508,  509,  518,  339,   59,  527,
  355,  515,  516,  517,  518,   59,  421,  421,   59,  531,
   59,  366,   59,  368,   59,   59,  358,  531,   59,   59,
   59,   59,   59,   59,   59,   59,  459,  460,   59,  384,
   59,   59,  398,   59,   61,   59,   61,  421,  521,  522,
  398,  524,  525,  526,  386,  387,   59,  398,  403,  421,
  398,  421,   61,   59,  396,  398,   59,  398,  398,  421,
  398,  421,  421,   59,  398,  466,  466,   59,  421,   59,
   59,  421,   59,   59,  421,  466,   59,   59,  473,  474,
  475,  476,  477,  438,  479,  480,  519,  482,  483,  484,
  485,  486,  447,  448,  489,   59,   59,  439,   59,  454,
  455,   59,  466,   59,  499,  500,  501,  502,  503,  504,
  421,  421,  507,   59,  421,  510,   59,  421,  460,  473,
  474,  475,  476,  477,   59,  479,  480,   59,  482,  483,
  484,  485,  486,  421,  397,  489,  421,   59,  466,   59,
   59,   59,   59,   59,   59,  499,  500,  501,  502,  503,
  504,   59,   59,  507,   59,   59,  510,  473,  474,  475,
  476,  477,  426,  479,  480,   59,  482,  483,  484,  485,
  486,   59,   59,  489,   44,  421,  466,  421,  471,   61,
  466,  421,  466,  499,  500,  501,  502,  503,  504,  466,
  466,  507,  466,   61,  510,  466,   59,  466,  466,  466,
  466,  421,  421,  421,  466,  466,  466,   59,  466,   59,
  466,   59,   59,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,   59,   59,   59,   59,   59,  397,   59,
   59,   59,   59,   59,   59,   59,   59,   59,  398,   59,
   59,   59,   59,   59,   59,   59,   59,   59,   59,   59,
  397,   59,   59,   59,   59,   59,   59,   59,   59,   59,
   59,   59,   59,   59,  123,   59,   59,  345,  404,  289,
 1605,  906, 1585,  306, 1583, 1509, 1386,  523,   73, 1493,
 1491,  622,  557, 1563, 1565, 1568,  675, 1566, 1507,  588,
 1484,  417,  123,  710,  205,  496, 1488,  396,  630,  547,
 1490,  322,  123,   -1,   -1,   -1,   -1, 1337,  100,   -1,
   -1, 1335,   -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
   -1,   -1,   -1,   -1,   -1,  134,
};
#define YYFINAL 1
#ifndef YYDEBUG
#define YYDEBUG 0
#endif
#define YYMAXTOKEN 533
#if YYDEBUG
static const char *yyname[] = {

"end-of-file",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,"','",0,0,0,0,0,0,0,0,0,0,0,0,0,0,"';'",0,"'='",0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,"'{'",0,"'}'",0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
"ACCEPT_PASSWORD","ACTION","ADMIN","AFTYPE","T_ALLOW","ANTI_NICK_FLOOD",
"ANTI_SPAM_EXIT_MESSAGE_TIME","ANTI_SPAM_CONNECT_NUMERIC","AUTOCONN","T_BLOCK",
"BURST_AWAY","BURST_TOPICWHO","BYTES","KBYTES","MBYTES","GBYTES","TBYTES",
"CALLER_ID_WAIT","CAN_FLOOD","CAN_IDLE","CHANNEL","CIDR_BITLEN_IPV4",
"CIDR_BITLEN_IPV6","CIPHER_PREFERENCE","CLASS","CLIENTCERT_HASH","CLOAK_KEY1",
"CLOAK_KEY2","CLOAK_KEY3","CLOAK_WHOIS_ACTUALLY","ACCOUNT_WHOIS","COMPRESSED",
"COMPRESSION_LEVEL","CONNECT","CONNECTFREQ","CRYPTLINK","CYCLE_ON_HOSTCHANGE",
"DEFAULT_CIPHER_PREFERENCE","DEFAULT_FLOODCOUNT","DEFAULT_SPLIT_SERVER_COUNT",
"DEFAULT_SPLIT_USER_COUNT","DENY","DESCRIPTION","DIE","DISABLE_AUTH",
"DISABLE_FAKE_CHANNELS","DISABLE_HIDDEN","DISABLE_LOCAL_CHANNELS",
"DISABLE_REMOTE_COMMANDS","DNSBL","DOT_IN_IP6_ADDR","DOTS_IN_IDENT","DURATION",
"EGDPOOL_PATH","EMAIL","ENABLE","ENCRYPTED","EXCEED_LIMIT","EXEMPT",
"FAILED_OPER_NOTICE","FAKENAME","IRCD_FLAGS","FLATTEN_LINKS","FFAILED_OPERLOG",
"FKILLLOG","FKLINELOG","FGLINELOG","FIOERRLOG","FOPERLOG","FOPERSPYLOG",
"FUSERLOG","GECOS","GENERAL","GLINE","GLINES","GLINE_EXEMPT","GLINE_LOG",
"GLINE_TIME","GLINE_MIN_CIDR","GLINE_MIN_CIDR6","GLOBAL_KILL","IRCD_AUTH",
"NEED_IDENT","HAVENT_READ_CONF","HIDDEN","HIDDEN_ADMIN","HIDDEN_NAME",
"HIDDEN_OPER","HIDE_SERVER_IPS","HIDE_SERVERS","HIDE_SPOOF_IPS","HOST","HUB",
"HUB_MASK","IDLETIME","IGNORE_BOGUS_TS","INVISIBLE_ON_CONNECT","IP","KILL",
"KILL_CHASE_TIME_LIMIT","KLINE","KLINE_EXEMPT","KLINE_REASON",
"KLINE_WITH_REASON","KNOCK_DELAY","KNOCK_DELAY_CHANNEL","LAZYLINK","LEAF_MASK",
"LINKS_DELAY","LISTEN","T_LOG","LOGGING","LOG_LEVEL","MAX_ACCEPT","MAX_BANS",
"MAX_CHANS_PER_USER","MAX_GLOBAL","MAX_IDENT","MAX_LOCAL","MAX_NICK_CHANGES",
"MAX_NICK_TIME","MAX_NUMBER","MAX_TARGETS","MESSAGE_LOCALE","MIN_NONWILDCARD",
"MIN_NONWILDCARD_SIMPLE","MODULE","MODULES","NAME","NEED_PASSWORD","IS_WEBIRC",
"NETWORK_DESC","NETWORK_NAME","NICK","NICK_CHANGES","NICK_COLLIDE_REALHOST",
"NO_CREATE_ON_SPLIT","NO_JOIN_ON_SPLIT","NO_OPER_FLOOD","NO_TILDE","NOT",
"NUMBER","NUMBER_PER_IDENT","NUMBER_PER_CIDR","NUMBER_PER_IP",
"NUMBER_PER_IP_GLOBAL","OPERATOR","OPERS_BYPASS_CALLERID","OPER_LOG",
"OPER_ONLY_UMODES","OPER_PASS_RESV","OPER_SPY_T","OPER_FARCONNECT",
"OPER_UMODES","JOIN_FLOOD_COUNT","JOIN_FLOOD_TIME","PACE_WAIT",
"PACE_WAIT_SIMPLE","PASSWORD","PATH","PING_COOKIE","PING_TIME","PING_WARNING",
"PORT","QSTRING","QUIET_ON_BAN","REASON","REDIRPORT","REDIRSERV","REGEX_T",
"REHASH","TREJECT_HOLD_TIME","REMOTE","REMOTEBAN","RESTRICT_CHANNELS",
"RESTRICTED","RSA_PRIVATE_KEY_FILE","RSA_PUBLIC_KEY_FILE",
"RSA_CRYPTLINK_KEY_FILE","SSL_CERTIFICATE_FILE","SSL_DH_PARAM_FILE","RESV",
"RESV_EXEMPT","SECONDS","MINUTES","HOURS","DAYS","WEEKS","SENDQ",
"SEND_PASSWORD","SERVERHIDE","SERVERINFO","SERVICES","SERVICES_NAME",
"SERVLINK_PATH","IRCD_SID","TKLINE_EXPIRE_NOTICES","T_SHARED","T_CLUSTER",
"TYPE","SHORT_MOTD","SILENT","SPOOF","SPOOF_NOTICE","STATS_E_DISABLED",
"STATS_I_OPER_ONLY","STATS_K_OPER_ONLY","STATS_O_OPER_ONLY","STATS_P_OPER_ONLY",
"TBOOL","TMASKED","T_REJECT","TS_MAX_DELTA","TS_WARN_DELTA","TWODOTS","T_ALL",
"T_BOTS","T_SOFTCALLERID","T_CALLERID","T_CCONN","T_NOCTCP","T_CLIENT_FLOOD",
"T_DEAF","T_DEBUG","T_DRONE","T_EXTERNAL","T_FULL","T_HIDECHANNELS",
"T_FARCONNECT","T_INVISIBLE","T_IPV4","T_IPV6","T_LOCOPS","T_LOGPATH",
"T_L_CRIT","T_L_DEBUG","T_L_ERROR","T_L_INFO","T_L_NOTICE","T_L_TRACE",
"T_L_WARN","T_MAX_CLIENTS","T_NCHANGE","T_OPERWALL","T_REJ","T_SERVNOTICE",
"T_SKILL","T_SPY","T_SSL","T_UMODES","T_UNAUTH","T_UNRESV","T_UNXLINE",
"T_WALLOP","THROTTLE_TIME","THROTTLE_NUM","TOPICBURST","TRUE_NO_OPER_FLOOD",
"TKLINE","TXLINE","TRESV","UNKLINE","USER","USE_EGD","USE_EXCEPT","USE_INVEX",
"HIDE_KILLER","USE_REGEX_BANS","USE_KNOCK","USE_NOCTCP","USE_LOGGING",
"USE_WHOIS_ACTUALLY","VHOST","VHOST6","XLINE","WARN","WARN_NO_NLINE",
};
static const char *yyrule[] = {
"$accept : conf",
"conf :",
"conf : conf conf_item",
"conf_item : admin_entry",
"conf_item : logging_entry",
"conf_item : oper_entry",
"conf_item : channel_entry",
"conf_item : class_entry",
"conf_item : listen_entry",
"conf_item : auth_entry",
"conf_item : serverinfo_entry",
"conf_item : serverhide_entry",
"conf_item : resv_entry",
"conf_item : shared_entry",
"conf_item : cluster_entry",
"conf_item : connect_entry",
"conf_item : kill_entry",
"conf_item : deny_entry",
"conf_item : exempt_entry",
"conf_item : general_entry",
"conf_item : gline_entry",
"conf_item : gecos_entry",
"conf_item : modules_entry",
"conf_item : dnsbl_entry",
"conf_item : error ';'",
"conf_item : error '}'",
"timespec_ :",
"timespec_ : timespec",
"timespec : NUMBER timespec_",
"timespec : NUMBER SECONDS timespec_",
"timespec : NUMBER MINUTES timespec_",
"timespec : NUMBER HOURS timespec_",
"timespec : NUMBER DAYS timespec_",
"timespec : NUMBER WEEKS timespec_",
"sizespec_ :",
"sizespec_ : sizespec",
"sizespec : NUMBER sizespec_",
"sizespec : NUMBER BYTES sizespec_",
"sizespec : NUMBER KBYTES sizespec_",
"sizespec : NUMBER MBYTES sizespec_",
"modules_entry : MODULES '{' modules_items '}' ';'",
"modules_items : modules_items modules_item",
"modules_items : modules_item",
"modules_item : modules_module",
"modules_item : modules_path",
"modules_item : error ';'",
"modules_module : MODULE '=' QSTRING ';'",
"modules_path : PATH '=' QSTRING ';'",
"$$1 :",
"dnsbl_entry : DNSBL $$1 '{' dnsbl_items '}' ';'",
"dnsbl_items : dnsbl_items dnsbl_item",
"dnsbl_items : dnsbl_item",
"dnsbl_item : dnsbl_name",
"dnsbl_item : dnsbl_duration",
"dnsbl_item : dnsbl_reason",
"dnsbl_item : error ';'",
"dnsbl_name : NAME '=' QSTRING ';'",
"dnsbl_duration : DURATION '=' timespec ';'",
"dnsbl_reason : REASON '=' QSTRING ';'",
"serverinfo_entry : SERVERINFO '{' serverinfo_items '}' ';'",
"serverinfo_items : serverinfo_items serverinfo_item",
"serverinfo_items : serverinfo_item",
"serverinfo_item : serverinfo_name",
"serverinfo_item : serverinfo_vhost",
"serverinfo_item : serverinfo_hub",
"serverinfo_item : serverinfo_description",
"serverinfo_item : serverinfo_network_name",
"serverinfo_item : serverinfo_network_desc",
"serverinfo_item : serverinfo_max_clients",
"serverinfo_item : serverinfo_rsa_private_key_file",
"serverinfo_item : serverinfo_rsa_cryptlink_key_file",
"serverinfo_item : serverinfo_vhost6",
"serverinfo_item : serverinfo_sid",
"serverinfo_item : serverinfo_ssl_certificate_file",
"serverinfo_item : serverinfo_ssl_dh_param_file",
"serverinfo_item : error ';'",
"serverinfo_ssl_certificate_file : SSL_CERTIFICATE_FILE '=' QSTRING ';'",
"serverinfo_ssl_dh_param_file : SSL_DH_PARAM_FILE '=' QSTRING ';'",
"serverinfo_rsa_private_key_file : RSA_PRIVATE_KEY_FILE '=' QSTRING ';'",
"serverinfo_rsa_cryptlink_key_file : RSA_CRYPTLINK_KEY_FILE '=' QSTRING ';'",
"serverinfo_name : NAME '=' QSTRING ';'",
"serverinfo_sid : IRCD_SID '=' QSTRING ';'",
"serverinfo_description : DESCRIPTION '=' QSTRING ';'",
"serverinfo_network_name : NETWORK_NAME '=' QSTRING ';'",
"serverinfo_network_desc : NETWORK_DESC '=' QSTRING ';'",
"serverinfo_vhost : VHOST '=' QSTRING ';'",
"serverinfo_vhost6 : VHOST6 '=' QSTRING ';'",
"serverinfo_max_clients : T_MAX_CLIENTS '=' NUMBER ';'",
"serverinfo_hub : HUB '=' TBOOL ';'",
"admin_entry : ADMIN '{' admin_items '}' ';'",
"admin_items : admin_items admin_item",
"admin_items : admin_item",
"admin_item : admin_name",
"admin_item : admin_description",
"admin_item : admin_email",
"admin_item : error ';'",
"admin_name : NAME '=' QSTRING ';'",
"admin_email : EMAIL '=' QSTRING ';'",
"admin_description : DESCRIPTION '=' QSTRING ';'",
"logging_entry : LOGGING '{' logging_items '}' ';'",
"logging_items : logging_items logging_item",
"logging_items : logging_item",
"logging_item : logging_path",
"logging_item : logging_oper_log",
"logging_item : logging_log_level",
"logging_item : logging_use_logging",
"logging_item : logging_fuserlog",
"logging_item : logging_foperlog",
"logging_item : logging_fglinelog",
"logging_item : logging_fklinelog",
"logging_item : logging_killlog",
"logging_item : logging_foperspylog",
"logging_item : logging_ioerrlog",
"logging_item : logging_ffailed_operlog",
"logging_item : error ';'",
"logging_path : T_LOGPATH '=' QSTRING ';'",
"logging_oper_log : OPER_LOG '=' QSTRING ';'",
"logging_fuserlog : FUSERLOG '=' QSTRING ';'",
"logging_ffailed_operlog : FFAILED_OPERLOG '=' QSTRING ';'",
"logging_foperlog : FOPERLOG '=' QSTRING ';'",
"logging_foperspylog : FOPERSPYLOG '=' QSTRING ';'",
"logging_fglinelog : FGLINELOG '=' QSTRING ';'",
"logging_fklinelog : FKLINELOG '=' QSTRING ';'",
"logging_ioerrlog : FIOERRLOG '=' QSTRING ';'",
"logging_killlog : FKILLLOG '=' QSTRING ';'",
"logging_log_level : LOG_LEVEL '=' T_L_CRIT ';'",
"logging_log_level : LOG_LEVEL '=' T_L_ERROR ';'",
"logging_log_level : LOG_LEVEL '=' T_L_WARN ';'",
"logging_log_level : LOG_LEVEL '=' T_L_NOTICE ';'",
"logging_log_level : LOG_LEVEL '=' T_L_TRACE ';'",
"logging_log_level : LOG_LEVEL '=' T_L_INFO ';'",
"logging_log_level : LOG_LEVEL '=' T_L_DEBUG ';'",
"logging_use_logging : USE_LOGGING '=' TBOOL ';'",
"$$2 :",
"oper_entry : OPERATOR $$2 oper_name_b '{' oper_items '}' ';'",
"oper_name_b :",
"oper_name_b : oper_name_t",
"oper_items : oper_items oper_item",
"oper_items : oper_item",
"oper_item : oper_name",
"oper_item : oper_user",
"oper_item : oper_password",
"oper_item : oper_hidden_admin",
"oper_item : oper_hidden_oper",
"oper_item : oper_umodes",
"oper_item : oper_class",
"oper_item : oper_global_kill",
"oper_item : oper_remote",
"oper_item : oper_kline",
"oper_item : oper_xline",
"oper_item : oper_unkline",
"oper_item : oper_gline",
"oper_item : oper_nick_changes",
"oper_item : oper_remoteban",
"oper_item : oper_die",
"oper_item : oper_rehash",
"oper_item : oper_admin",
"oper_item : oper_operwall",
"oper_item : oper_encrypted",
"oper_item : oper_rsa_public_key_file",
"oper_item : oper_client_certificate_hash",
"oper_item : oper_spy",
"oper_item : oper_flags",
"oper_item : error ';'",
"oper_name : NAME '=' QSTRING ';'",
"oper_name_t : QSTRING",
"oper_user : USER '=' QSTRING ';'",
"oper_client_certificate_hash : CLIENTCERT_HASH '=' QSTRING ';'",
"oper_password : PASSWORD '=' QSTRING ';'",
"oper_encrypted : ENCRYPTED '=' TBOOL ';'",
"oper_rsa_public_key_file : RSA_PUBLIC_KEY_FILE '=' QSTRING ';'",
"oper_class : CLASS '=' QSTRING ';'",
"$$3 :",
"oper_umodes : T_UMODES $$3 '=' oper_umodes_items ';'",
"oper_umodes_items : oper_umodes_items ',' oper_umodes_item",
"oper_umodes_items : oper_umodes_item",
"oper_umodes_item : T_BOTS",
"oper_umodes_item : T_CCONN",
"oper_umodes_item : T_NOCTCP",
"oper_umodes_item : T_DEAF",
"oper_umodes_item : T_DEBUG",
"oper_umodes_item : T_FULL",
"oper_umodes_item : T_SKILL",
"oper_umodes_item : T_NCHANGE",
"oper_umodes_item : T_REJ",
"oper_umodes_item : T_UNAUTH",
"oper_umodes_item : T_SPY",
"oper_umodes_item : T_EXTERNAL",
"oper_umodes_item : T_OPERWALL",
"oper_umodes_item : T_SERVNOTICE",
"oper_umodes_item : T_INVISIBLE",
"oper_umodes_item : T_WALLOP",
"oper_umodes_item : T_SOFTCALLERID",
"oper_umodes_item : T_CALLERID",
"oper_umodes_item : T_LOCOPS",
"oper_umodes_item : T_HIDECHANNELS",
"oper_umodes_item : T_FARCONNECT",
"oper_global_kill : GLOBAL_KILL '=' TBOOL ';'",
"oper_remote : REMOTE '=' TBOOL ';'",
"oper_remoteban : REMOTEBAN '=' TBOOL ';'",
"oper_kline : KLINE '=' TBOOL ';'",
"oper_xline : XLINE '=' TBOOL ';'",
"oper_unkline : UNKLINE '=' TBOOL ';'",
"oper_gline : GLINE '=' TBOOL ';'",
"oper_nick_changes : NICK_CHANGES '=' TBOOL ';'",
"oper_die : DIE '=' TBOOL ';'",
"oper_rehash : REHASH '=' TBOOL ';'",
"oper_admin : ADMIN '=' TBOOL ';'",
"oper_hidden_admin : HIDDEN_ADMIN '=' TBOOL ';'",
"oper_hidden_oper : HIDDEN_OPER '=' TBOOL ';'",
"oper_spy : OPER_SPY_T '=' TBOOL ';'",
"oper_operwall : T_OPERWALL '=' TBOOL ';'",
"$$4 :",
"oper_flags : IRCD_FLAGS $$4 '=' oper_flags_items ';'",
"oper_flags_items : oper_flags_items ',' oper_flags_item",
"oper_flags_items : oper_flags_item",
"$$5 :",
"oper_flags_item : NOT $$5 oper_flags_item_atom",
"$$6 :",
"oper_flags_item : $$6 oper_flags_item_atom",
"oper_flags_item_atom : GLOBAL_KILL",
"oper_flags_item_atom : REMOTE",
"oper_flags_item_atom : KLINE",
"oper_flags_item_atom : UNKLINE",
"oper_flags_item_atom : XLINE",
"oper_flags_item_atom : GLINE",
"oper_flags_item_atom : DIE",
"oper_flags_item_atom : REHASH",
"oper_flags_item_atom : ADMIN",
"oper_flags_item_atom : HIDDEN_ADMIN",
"oper_flags_item_atom : NICK_CHANGES",
"oper_flags_item_atom : T_OPERWALL",
"oper_flags_item_atom : OPER_SPY_T",
"oper_flags_item_atom : HIDDEN_OPER",
"oper_flags_item_atom : REMOTEBAN",
"oper_flags_item_atom : ENCRYPTED",
"oper_flags_item_atom : OPER_FARCONNECT",
"$$7 :",
"class_entry : CLASS $$7 class_name_b '{' class_items '}' ';'",
"class_name_b :",
"class_name_b : class_name_t",
"class_items : class_items class_item",
"class_items : class_item",
"class_item : class_name",
"class_item : class_cidr_bitlen_ipv4",
"class_item : class_cidr_bitlen_ipv6",
"class_item : class_ping_time",
"class_item : class_ping_warning",
"class_item : class_number_per_cidr",
"class_item : class_number_per_ip",
"class_item : class_connectfreq",
"class_item : class_max_number",
"class_item : class_max_global",
"class_item : class_max_local",
"class_item : class_max_ident",
"class_item : class_sendq",
"class_item : error ';'",
"class_name : NAME '=' QSTRING ';'",
"class_name_t : QSTRING",
"class_ping_time : PING_TIME '=' timespec ';'",
"class_ping_warning : PING_WARNING '=' timespec ';'",
"class_number_per_ip : NUMBER_PER_IP '=' NUMBER ';'",
"class_connectfreq : CONNECTFREQ '=' timespec ';'",
"class_max_number : MAX_NUMBER '=' NUMBER ';'",
"class_max_global : MAX_GLOBAL '=' NUMBER ';'",
"class_max_local : MAX_LOCAL '=' NUMBER ';'",
"class_max_ident : MAX_IDENT '=' NUMBER ';'",
"class_sendq : SENDQ '=' sizespec ';'",
"class_cidr_bitlen_ipv4 : CIDR_BITLEN_IPV4 '=' NUMBER ';'",
"class_cidr_bitlen_ipv6 : CIDR_BITLEN_IPV6 '=' NUMBER ';'",
"class_number_per_cidr : NUMBER_PER_CIDR '=' NUMBER ';'",
"$$8 :",
"listen_entry : LISTEN $$8 '{' listen_items '}' ';'",
"$$9 :",
"listen_flags : IRCD_FLAGS $$9 '=' listen_flags_items ';'",
"listen_flags_items : listen_flags_items ',' listen_flags_item",
"listen_flags_items : listen_flags_item",
"listen_flags_item : T_SSL",
"listen_flags_item : HIDDEN",
"listen_items : listen_items listen_item",
"listen_items : listen_item",
"listen_item : listen_port",
"listen_item : listen_flags",
"listen_item : listen_address",
"listen_item : listen_host",
"listen_item : error ';'",
"$$10 :",
"listen_port : PORT '=' port_items $$10 ';'",
"port_items : port_items ',' port_item",
"port_items : port_item",
"port_item : NUMBER",
"port_item : NUMBER TWODOTS NUMBER",
"listen_address : IP '=' QSTRING ';'",
"listen_host : HOST '=' QSTRING ';'",
"$$11 :",
"auth_entry : IRCD_AUTH $$11 '{' auth_items '}' ';'",
"auth_items : auth_items auth_item",
"auth_items : auth_item",
"auth_item : auth_user",
"auth_item : auth_passwd",
"auth_item : auth_class",
"auth_item : auth_flags",
"auth_item : auth_kline_exempt",
"auth_item : auth_need_ident",
"auth_item : auth_exceed_limit",
"auth_item : auth_no_tilde",
"auth_item : auth_gline_exempt",
"auth_item : auth_spoof",
"auth_item : auth_spoof_notice",
"auth_item : auth_webirc",
"auth_item : auth_redir_serv",
"auth_item : auth_redir_port",
"auth_item : auth_can_flood",
"auth_item : auth_need_password",
"auth_item : auth_encrypted",
"auth_item : auth_client_certificate_hash",
"auth_item : error ';'",
"auth_user : USER '=' QSTRING ';'",
"auth_passwd : PASSWORD '=' QSTRING ';'",
"auth_client_certificate_hash : CLIENTCERT_HASH '=' QSTRING ';'",
"auth_spoof_notice : SPOOF_NOTICE '=' TBOOL ';'",
"auth_class : CLASS '=' QSTRING ';'",
"auth_encrypted : ENCRYPTED '=' TBOOL ';'",
"$$12 :",
"auth_flags : IRCD_FLAGS $$12 '=' auth_flags_items ';'",
"auth_flags_items : auth_flags_items ',' auth_flags_item",
"auth_flags_items : auth_flags_item",
"$$13 :",
"auth_flags_item : NOT $$13 auth_flags_item_atom",
"$$14 :",
"auth_flags_item : $$14 auth_flags_item_atom",
"auth_flags_item_atom : SPOOF_NOTICE",
"auth_flags_item_atom : EXCEED_LIMIT",
"auth_flags_item_atom : KLINE_EXEMPT",
"auth_flags_item_atom : NEED_IDENT",
"auth_flags_item_atom : CAN_FLOOD",
"auth_flags_item_atom : CAN_IDLE",
"auth_flags_item_atom : NO_TILDE",
"auth_flags_item_atom : GLINE_EXEMPT",
"auth_flags_item_atom : RESV_EXEMPT",
"auth_flags_item_atom : IS_WEBIRC",
"auth_flags_item_atom : NEED_PASSWORD",
"auth_kline_exempt : KLINE_EXEMPT '=' TBOOL ';'",
"auth_need_ident : NEED_IDENT '=' TBOOL ';'",
"auth_exceed_limit : EXCEED_LIMIT '=' TBOOL ';'",
"auth_can_flood : CAN_FLOOD '=' TBOOL ';'",
"auth_no_tilde : NO_TILDE '=' TBOOL ';'",
"auth_gline_exempt : GLINE_EXEMPT '=' TBOOL ';'",
"auth_spoof : SPOOF '=' QSTRING ';'",
"auth_redir_serv : REDIRSERV '=' QSTRING ';'",
"auth_redir_port : REDIRPORT '=' NUMBER ';'",
"auth_webirc : IS_WEBIRC '=' TBOOL ';'",
"auth_need_password : NEED_PASSWORD '=' TBOOL ';'",
"$$15 :",
"resv_entry : RESV $$15 '{' resv_items '}' ';'",
"resv_items : resv_items resv_item",
"resv_items : resv_item",
"resv_item : resv_creason",
"resv_item : resv_channel",
"resv_item : resv_nick",
"resv_item : error ';'",
"resv_creason : REASON '=' QSTRING ';'",
"resv_channel : CHANNEL '=' QSTRING ';'",
"resv_nick : NICK '=' QSTRING ';'",
"$$16 :",
"shared_entry : T_SHARED $$16 '{' shared_items '}' ';'",
"shared_items : shared_items shared_item",
"shared_items : shared_item",
"shared_item : shared_name",
"shared_item : shared_user",
"shared_item : shared_type",
"shared_item : error ';'",
"shared_name : NAME '=' QSTRING ';'",
"shared_user : USER '=' QSTRING ';'",
"$$17 :",
"shared_type : TYPE $$17 '=' shared_types ';'",
"shared_types : shared_types ',' shared_type_item",
"shared_types : shared_type_item",
"shared_type_item : KLINE",
"shared_type_item : TKLINE",
"shared_type_item : UNKLINE",
"shared_type_item : XLINE",
"shared_type_item : TXLINE",
"shared_type_item : T_UNXLINE",
"shared_type_item : RESV",
"shared_type_item : TRESV",
"shared_type_item : T_UNRESV",
"shared_type_item : T_LOCOPS",
"shared_type_item : SERVICES",
"shared_type_item : REHASH",
"shared_type_item : T_ALL",
"$$18 :",
"cluster_entry : T_CLUSTER $$18 '{' cluster_items '}' ';'",
"cluster_items : cluster_items cluster_item",
"cluster_items : cluster_item",
"cluster_item : cluster_name",
"cluster_item : cluster_type",
"cluster_item : error ';'",
"cluster_name : NAME '=' QSTRING ';'",
"$$19 :",
"cluster_type : TYPE $$19 '=' cluster_types ';'",
"cluster_types : cluster_types ',' cluster_type_item",
"cluster_types : cluster_type_item",
"cluster_type_item : KLINE",
"cluster_type_item : TKLINE",
"cluster_type_item : UNKLINE",
"cluster_type_item : XLINE",
"cluster_type_item : TXLINE",
"cluster_type_item : T_UNXLINE",
"cluster_type_item : RESV",
"cluster_type_item : TRESV",
"cluster_type_item : T_UNRESV",
"cluster_type_item : T_LOCOPS",
"cluster_type_item : T_ALL",
"$$20 :",
"connect_entry : CONNECT $$20 connect_name_b '{' connect_items '}' ';'",
"connect_name_b :",
"connect_name_b : connect_name_t",
"connect_items : connect_items connect_item",
"connect_items : connect_item",
"connect_item : connect_name",
"connect_item : connect_host",
"connect_item : connect_vhost",
"connect_item : connect_send_password",
"connect_item : connect_accept_password",
"connect_item : connect_aftype",
"connect_item : connect_port",
"connect_item : connect_fakename",
"connect_item : connect_flags",
"connect_item : connect_hub_mask",
"connect_item : connect_leaf_mask",
"connect_item : connect_class",
"connect_item : connect_auto",
"connect_item : connect_encrypted",
"connect_item : connect_compressed",
"connect_item : connect_cryptlink",
"connect_item : connect_rsa_public_key_file",
"connect_item : connect_cipher_preference",
"connect_item : connect_topicburst",
"connect_item : error ';'",
"connect_name : NAME '=' QSTRING ';'",
"connect_name_t : QSTRING",
"connect_host : HOST '=' QSTRING ';'",
"connect_vhost : VHOST '=' QSTRING ';'",
"connect_send_password : SEND_PASSWORD '=' QSTRING ';'",
"connect_accept_password : ACCEPT_PASSWORD '=' QSTRING ';'",
"connect_port : PORT '=' NUMBER ';'",
"connect_aftype : AFTYPE '=' T_IPV4 ';'",
"connect_aftype : AFTYPE '=' T_IPV6 ';'",
"connect_fakename : FAKENAME '=' QSTRING ';'",
"$$21 :",
"connect_flags : IRCD_FLAGS $$21 '=' connect_flags_items ';'",
"connect_flags_items : connect_flags_items ',' connect_flags_item",
"connect_flags_items : connect_flags_item",
"$$22 :",
"connect_flags_item : NOT $$22 connect_flags_item_atom",
"$$23 :",
"connect_flags_item : $$23 connect_flags_item_atom",
"connect_flags_item_atom : LAZYLINK",
"connect_flags_item_atom : COMPRESSED",
"connect_flags_item_atom : CRYPTLINK",
"connect_flags_item_atom : AUTOCONN",
"connect_flags_item_atom : BURST_AWAY",
"connect_flags_item_atom : TOPICBURST",
"connect_rsa_public_key_file : RSA_PUBLIC_KEY_FILE '=' QSTRING ';'",
"connect_encrypted : ENCRYPTED '=' TBOOL ';'",
"connect_cryptlink : CRYPTLINK '=' TBOOL ';'",
"connect_compressed : COMPRESSED '=' TBOOL ';'",
"connect_auto : AUTOCONN '=' TBOOL ';'",
"connect_topicburst : TOPICBURST '=' TBOOL ';'",
"connect_hub_mask : HUB_MASK '=' QSTRING ';'",
"connect_leaf_mask : LEAF_MASK '=' QSTRING ';'",
"connect_class : CLASS '=' QSTRING ';'",
"connect_cipher_preference : CIPHER_PREFERENCE '=' QSTRING ';'",
"$$24 :",
"kill_entry : KILL $$24 '{' kill_items '}' ';'",
"$$25 :",
"kill_type : TYPE $$25 '=' kill_type_items ';'",
"kill_type_items : kill_type_items ',' kill_type_item",
"kill_type_items : kill_type_item",
"kill_type_item : REGEX_T",
"kill_items : kill_items kill_item",
"kill_items : kill_item",
"kill_item : kill_user",
"kill_item : kill_reason",
"kill_item : kill_type",
"kill_item : error",
"kill_user : USER '=' QSTRING ';'",
"kill_reason : REASON '=' QSTRING ';'",
"$$26 :",
"deny_entry : DENY $$26 '{' deny_items '}' ';'",
"deny_items : deny_items deny_item",
"deny_items : deny_item",
"deny_item : deny_ip",
"deny_item : deny_reason",
"deny_item : error",
"deny_ip : IP '=' QSTRING ';'",
"deny_reason : REASON '=' QSTRING ';'",
"exempt_entry : EXEMPT '{' exempt_items '}' ';'",
"exempt_items : exempt_items exempt_item",
"exempt_items : exempt_item",
"exempt_item : exempt_ip",
"exempt_item : exempt_client_certificate_hash",
"exempt_item : error",
"exempt_ip : IP '=' QSTRING ';'",
"exempt_client_certificate_hash : CLIENTCERT_HASH '=' QSTRING ';'",
"$$27 :",
"gecos_entry : GECOS $$27 '{' gecos_items '}' ';'",
"$$28 :",
"gecos_flags : TYPE $$28 '=' gecos_flags_items ';'",
"gecos_flags_items : gecos_flags_items ',' gecos_flags_item",
"gecos_flags_items : gecos_flags_item",
"gecos_flags_item : REGEX_T",
"gecos_items : gecos_items gecos_item",
"gecos_items : gecos_item",
"gecos_item : gecos_name",
"gecos_item : gecos_reason",
"gecos_item : gecos_flags",
"gecos_item : error",
"gecos_name : NAME '=' QSTRING ';'",
"gecos_reason : REASON '=' QSTRING ';'",
"general_entry : GENERAL '{' general_items '}' ';'",
"general_items : general_items general_item",
"general_items : general_item",
"general_item : general_hide_spoof_ips",
"general_item : general_ignore_bogus_ts",
"general_item : general_failed_oper_notice",
"general_item : general_anti_nick_flood",
"general_item : general_max_nick_time",
"general_item : general_max_nick_changes",
"general_item : general_max_accept",
"general_item : general_anti_spam_exit_message_time",
"general_item : general_anti_spam_connect_numeric",
"general_item : general_ts_warn_delta",
"general_item : general_ts_max_delta",
"general_item : general_kill_chase_time_limit",
"general_item : general_kline_with_reason",
"general_item : general_kline_reason",
"general_item : general_invisible_on_connect",
"general_item : general_warn_no_nline",
"general_item : general_dots_in_ident",
"general_item : general_stats_o_oper_only",
"general_item : general_stats_k_oper_only",
"general_item : general_pace_wait",
"general_item : general_stats_i_oper_only",
"general_item : general_pace_wait_simple",
"general_item : general_stats_P_oper_only",
"general_item : general_short_motd",
"general_item : general_no_oper_flood",
"general_item : general_true_no_oper_flood",
"general_item : general_oper_pass_resv",
"general_item : general_idletime",
"general_item : general_message_locale",
"general_item : general_oper_only_umodes",
"general_item : general_max_targets",
"general_item : general_use_egd",
"general_item : general_egdpool_path",
"general_item : general_oper_umodes",
"general_item : general_caller_id_wait",
"general_item : general_opers_bypass_callerid",
"general_item : general_default_floodcount",
"general_item : general_min_nonwildcard",
"general_item : general_min_nonwildcard_simple",
"general_item : general_servlink_path",
"general_item : general_disable_remote_commands",
"general_item : general_default_cipher_preference",
"general_item : general_stats_e_disabled",
"general_item : general_compression_level",
"general_item : general_client_flood",
"general_item : general_throttle_num",
"general_item : general_throttle_time",
"general_item : general_havent_read_conf",
"general_item : general_dot_in_ip6_addr",
"general_item : general_ping_cookie",
"general_item : general_disable_auth",
"general_item : general_burst_away",
"general_item : general_tkline_expire_notices",
"general_item : general_gline_min_cidr",
"general_item : general_gline_min_cidr6",
"general_item : general_use_whois_actually",
"general_item : general_reject_hold_time",
"general_item : general_hide_killer",
"general_item : general_cloak_key1",
"general_item : general_cloak_key2",
"general_item : general_cloak_key3",
"general_item : general_cloak_whois_actually",
"general_item : general_account_whois",
"general_item : general_services_name",
"general_item : general_nick_collide_realhost",
"general_item : error",
"general_gline_min_cidr : GLINE_MIN_CIDR '=' NUMBER ';'",
"general_gline_min_cidr6 : GLINE_MIN_CIDR6 '=' NUMBER ';'",
"general_burst_away : BURST_AWAY '=' TBOOL ';'",
"general_use_whois_actually : USE_WHOIS_ACTUALLY '=' TBOOL ';'",
"general_nick_collide_realhost : NICK_COLLIDE_REALHOST '=' TBOOL ';'",
"general_reject_hold_time : TREJECT_HOLD_TIME '=' timespec ';'",
"general_tkline_expire_notices : TKLINE_EXPIRE_NOTICES '=' TBOOL ';'",
"general_kill_chase_time_limit : KILL_CHASE_TIME_LIMIT '=' NUMBER ';'",
"general_hide_spoof_ips : HIDE_SPOOF_IPS '=' TBOOL ';'",
"general_ignore_bogus_ts : IGNORE_BOGUS_TS '=' TBOOL ';'",
"general_disable_remote_commands : DISABLE_REMOTE_COMMANDS '=' TBOOL ';'",
"general_failed_oper_notice : FAILED_OPER_NOTICE '=' TBOOL ';'",
"general_anti_nick_flood : ANTI_NICK_FLOOD '=' TBOOL ';'",
"general_max_nick_time : MAX_NICK_TIME '=' timespec ';'",
"general_max_nick_changes : MAX_NICK_CHANGES '=' NUMBER ';'",
"general_max_accept : MAX_ACCEPT '=' NUMBER ';'",
"general_anti_spam_exit_message_time : ANTI_SPAM_EXIT_MESSAGE_TIME '=' timespec ';'",
"general_anti_spam_connect_numeric : ANTI_SPAM_CONNECT_NUMERIC '=' TBOOL ';'",
"general_ts_warn_delta : TS_WARN_DELTA '=' timespec ';'",
"general_ts_max_delta : TS_MAX_DELTA '=' timespec ';'",
"general_havent_read_conf : HAVENT_READ_CONF '=' NUMBER ';'",
"general_kline_with_reason : KLINE_WITH_REASON '=' TBOOL ';'",
"general_kline_reason : KLINE_REASON '=' QSTRING ';'",
"general_cloak_key1 : CLOAK_KEY1 '=' QSTRING ';'",
"general_cloak_key2 : CLOAK_KEY2 '=' QSTRING ';'",
"general_cloak_key3 : CLOAK_KEY3 '=' QSTRING ';'",
"general_cloak_whois_actually : CLOAK_WHOIS_ACTUALLY '=' TBOOL ';'",
"general_account_whois : ACCOUNT_WHOIS '=' TBOOL ';'",
"general_services_name : SERVICES_NAME '=' QSTRING ';'",
"general_invisible_on_connect : INVISIBLE_ON_CONNECT '=' TBOOL ';'",
"general_warn_no_nline : WARN_NO_NLINE '=' TBOOL ';'",
"general_stats_e_disabled : STATS_E_DISABLED '=' TBOOL ';'",
"general_stats_o_oper_only : STATS_O_OPER_ONLY '=' TBOOL ';'",
"general_stats_P_oper_only : STATS_P_OPER_ONLY '=' TBOOL ';'",
"general_hide_killer : HIDE_KILLER '=' TBOOL ';'",
"general_stats_k_oper_only : STATS_K_OPER_ONLY '=' TBOOL ';'",
"general_stats_k_oper_only : STATS_K_OPER_ONLY '=' TMASKED ';'",
"general_stats_i_oper_only : STATS_I_OPER_ONLY '=' TBOOL ';'",
"general_stats_i_oper_only : STATS_I_OPER_ONLY '=' TMASKED ';'",
"general_pace_wait : PACE_WAIT '=' timespec ';'",
"general_caller_id_wait : CALLER_ID_WAIT '=' timespec ';'",
"general_opers_bypass_callerid : OPERS_BYPASS_CALLERID '=' TBOOL ';'",
"general_pace_wait_simple : PACE_WAIT_SIMPLE '=' timespec ';'",
"general_short_motd : SHORT_MOTD '=' TBOOL ';'",
"general_no_oper_flood : NO_OPER_FLOOD '=' TBOOL ';'",
"general_true_no_oper_flood : TRUE_NO_OPER_FLOOD '=' TBOOL ';'",
"general_oper_pass_resv : OPER_PASS_RESV '=' TBOOL ';'",
"general_message_locale : MESSAGE_LOCALE '=' QSTRING ';'",
"general_idletime : IDLETIME '=' timespec ';'",
"general_dots_in_ident : DOTS_IN_IDENT '=' NUMBER ';'",
"general_max_targets : MAX_TARGETS '=' NUMBER ';'",
"general_servlink_path : SERVLINK_PATH '=' QSTRING ';'",
"general_default_cipher_preference : DEFAULT_CIPHER_PREFERENCE '=' QSTRING ';'",
"general_compression_level : COMPRESSION_LEVEL '=' NUMBER ';'",
"general_use_egd : USE_EGD '=' TBOOL ';'",
"general_egdpool_path : EGDPOOL_PATH '=' QSTRING ';'",
"general_ping_cookie : PING_COOKIE '=' TBOOL ';'",
"general_disable_auth : DISABLE_AUTH '=' TBOOL ';'",
"general_throttle_num : THROTTLE_NUM '=' NUMBER ';'",
"general_throttle_time : THROTTLE_TIME '=' timespec ';'",
"$$29 :",
"general_oper_umodes : OPER_UMODES $$29 '=' umode_oitems ';'",
"umode_oitems : umode_oitems ',' umode_oitem",
"umode_oitems : umode_oitem",
"umode_oitem : T_BOTS",
"umode_oitem : T_CCONN",
"umode_oitem : T_NOCTCP",
"umode_oitem : T_DEAF",
"umode_oitem : T_DEBUG",
"umode_oitem : T_FULL",
"umode_oitem : T_SKILL",
"umode_oitem : T_NCHANGE",
"umode_oitem : T_REJ",
"umode_oitem : T_UNAUTH",
"umode_oitem : T_SPY",
"umode_oitem : T_EXTERNAL",
"umode_oitem : T_OPERWALL",
"umode_oitem : T_SERVNOTICE",
"umode_oitem : T_INVISIBLE",
"umode_oitem : T_WALLOP",
"umode_oitem : T_SOFTCALLERID",
"umode_oitem : T_CALLERID",
"umode_oitem : T_LOCOPS",
"umode_oitem : T_HIDECHANNELS",
"umode_oitem : T_FARCONNECT",
"$$30 :",
"general_oper_only_umodes : OPER_ONLY_UMODES $$30 '=' umode_items ';'",
"umode_items : umode_items ',' umode_item",
"umode_items : umode_item",
"umode_item : T_BOTS",
"umode_item : T_CCONN",
"umode_item : T_NOCTCP",
"umode_item : T_DEAF",
"umode_item : T_DEBUG",
"umode_item : T_FULL",
"umode_item : T_SKILL",
"umode_item : T_NCHANGE",
"umode_item : T_REJ",
"umode_item : T_UNAUTH",
"umode_item : T_SPY",
"umode_item : T_EXTERNAL",
"umode_item : T_OPERWALL",
"umode_item : T_SERVNOTICE",
"umode_item : T_INVISIBLE",
"umode_item : T_WALLOP",
"umode_item : T_SOFTCALLERID",
"umode_item : T_CALLERID",
"umode_item : T_LOCOPS",
"umode_item : T_HIDECHANNELS",
"umode_item : T_FARCONNECT",
"general_min_nonwildcard : MIN_NONWILDCARD '=' NUMBER ';'",
"general_min_nonwildcard_simple : MIN_NONWILDCARD_SIMPLE '=' NUMBER ';'",
"general_default_floodcount : DEFAULT_FLOODCOUNT '=' NUMBER ';'",
"general_client_flood : T_CLIENT_FLOOD '=' sizespec ';'",
"general_dot_in_ip6_addr : DOT_IN_IP6_ADDR '=' TBOOL ';'",
"$$31 :",
"gline_entry : GLINES $$31 '{' gline_items '}' ';'",
"gline_items : gline_items gline_item",
"gline_items : gline_item",
"gline_item : gline_enable",
"gline_item : gline_duration",
"gline_item : gline_logging",
"gline_item : gline_user",
"gline_item : gline_server",
"gline_item : gline_action",
"gline_item : error",
"gline_enable : ENABLE '=' TBOOL ';'",
"gline_duration : DURATION '=' timespec ';'",
"$$32 :",
"gline_logging : LOGGING $$32 '=' gline_logging_types ';'",
"gline_logging_types : gline_logging_types ',' gline_logging_type_item",
"gline_logging_types : gline_logging_type_item",
"gline_logging_type_item : T_REJECT",
"gline_logging_type_item : T_BLOCK",
"gline_user : USER '=' QSTRING ';'",
"gline_server : NAME '=' QSTRING ';'",
"$$33 :",
"gline_action : ACTION $$33 '=' gdeny_types ';'",
"gdeny_types : gdeny_types ',' gdeny_type_item",
"gdeny_types : gdeny_type_item",
"gdeny_type_item : T_REJECT",
"gdeny_type_item : T_BLOCK",
"channel_entry : CHANNEL '{' channel_items '}' ';'",
"channel_items : channel_items channel_item",
"channel_items : channel_item",
"channel_item : channel_disable_local_channels",
"channel_item : channel_use_except",
"channel_item : channel_use_invex",
"channel_item : channel_use_knock",
"channel_item : channel_use_noctcp",
"channel_item : channel_use_regex_bans",
"channel_item : channel_max_bans",
"channel_item : channel_knock_delay",
"channel_item : channel_knock_delay_channel",
"channel_item : channel_max_chans_per_user",
"channel_item : channel_quiet_on_ban",
"channel_item : channel_default_split_user_count",
"channel_item : channel_default_split_server_count",
"channel_item : channel_no_create_on_split",
"channel_item : channel_restrict_channels",
"channel_item : channel_no_join_on_split",
"channel_item : channel_burst_topicwho",
"channel_item : channel_jflood_count",
"channel_item : channel_jflood_time",
"channel_item : channel_disable_fake_channels",
"channel_item : channel_cycle_on_hostchange",
"channel_item : error",
"channel_cycle_on_hostchange : CYCLE_ON_HOSTCHANGE '=' TBOOL ';'",
"channel_disable_fake_channels : DISABLE_FAKE_CHANNELS '=' TBOOL ';'",
"channel_restrict_channels : RESTRICT_CHANNELS '=' TBOOL ';'",
"channel_disable_local_channels : DISABLE_LOCAL_CHANNELS '=' TBOOL ';'",
"channel_use_except : USE_EXCEPT '=' TBOOL ';'",
"channel_use_invex : USE_INVEX '=' TBOOL ';'",
"channel_use_regex_bans : USE_REGEX_BANS '=' TBOOL ';'",
"channel_use_knock : USE_KNOCK '=' TBOOL ';'",
"channel_use_noctcp : USE_NOCTCP '=' TBOOL ';'",
"channel_knock_delay : KNOCK_DELAY '=' timespec ';'",
"channel_knock_delay_channel : KNOCK_DELAY_CHANNEL '=' timespec ';'",
"channel_max_chans_per_user : MAX_CHANS_PER_USER '=' NUMBER ';'",
"channel_quiet_on_ban : QUIET_ON_BAN '=' TBOOL ';'",
"channel_max_bans : MAX_BANS '=' NUMBER ';'",
"channel_default_split_user_count : DEFAULT_SPLIT_USER_COUNT '=' NUMBER ';'",
"channel_default_split_server_count : DEFAULT_SPLIT_SERVER_COUNT '=' NUMBER ';'",
"channel_no_create_on_split : NO_CREATE_ON_SPLIT '=' TBOOL ';'",
"channel_no_join_on_split : NO_JOIN_ON_SPLIT '=' TBOOL ';'",
"channel_burst_topicwho : BURST_TOPICWHO '=' TBOOL ';'",
"channel_jflood_count : JOIN_FLOOD_COUNT '=' NUMBER ';'",
"channel_jflood_time : JOIN_FLOOD_TIME '=' timespec ';'",
"serverhide_entry : SERVERHIDE '{' serverhide_items '}' ';'",
"serverhide_items : serverhide_items serverhide_item",
"serverhide_items : serverhide_item",
"serverhide_item : serverhide_flatten_links",
"serverhide_item : serverhide_hide_servers",
"serverhide_item : serverhide_links_delay",
"serverhide_item : serverhide_disable_hidden",
"serverhide_item : serverhide_hidden",
"serverhide_item : serverhide_hidden_name",
"serverhide_item : serverhide_hide_server_ips",
"serverhide_item : error",
"serverhide_flatten_links : FLATTEN_LINKS '=' TBOOL ';'",
"serverhide_hide_servers : HIDE_SERVERS '=' TBOOL ';'",
"serverhide_hidden_name : HIDDEN_NAME '=' QSTRING ';'",
"serverhide_links_delay : LINKS_DELAY '=' timespec ';'",
"serverhide_hidden : HIDDEN '=' TBOOL ';'",
"serverhide_disable_hidden : DISABLE_HIDDEN '=' TBOOL ';'",
"serverhide_hide_server_ips : HIDE_SERVER_IPS '=' TBOOL ';'",

};
#endif

int      yydebug;
int      yynerrs;

int      yyerrflag;
int      yychar;
YYSTYPE  yyval;
YYSTYPE  yylval;

/* define the initial stack-sizes */
#ifdef YYSTACKSIZE
#undef YYMAXDEPTH
#define YYMAXDEPTH  YYSTACKSIZE
#else
#ifdef YYMAXDEPTH
#define YYSTACKSIZE YYMAXDEPTH
#else
#define YYSTACKSIZE 10000
#define YYMAXDEPTH  10000
#endif
#endif

#define YYINITSTACKSIZE 200

typedef struct {
    unsigned stacksize;
    short    *s_base;
    short    *s_mark;
    short    *s_last;
    YYSTYPE  *l_base;
    YYSTYPE  *l_mark;
} YYSTACKDATA;
/* variables for the parser stack */
static YYSTACKDATA yystack;

#if YYDEBUG
#include <stdio.h>		/* needed for printf */
#endif

#include <stdlib.h>	/* needed for malloc, etc */
#include <string.h>	/* needed for memset */

/* allocate initial stack or double stack size, up to YYMAXDEPTH */
static int yygrowstack(YYSTACKDATA *data)
{
    int i;
    unsigned newsize;
    short *newss;
    YYSTYPE *newvs;

    if ((newsize = data->stacksize) == 0)
        newsize = YYINITSTACKSIZE;
    else if (newsize >= YYMAXDEPTH)
        return -1;
    else if ((newsize *= 2) > YYMAXDEPTH)
        newsize = YYMAXDEPTH;

    i = (int) (data->s_mark - data->s_base);
    newss = (short *)realloc(data->s_base, newsize * sizeof(*newss));
    if (newss == 0)
        return -1;

    data->s_base = newss;
    data->s_mark = newss + i;

    newvs = (YYSTYPE *)realloc(data->l_base, newsize * sizeof(*newvs));
    if (newvs == 0)
        return -1;

    data->l_base = newvs;
    data->l_mark = newvs + i;

    data->stacksize = newsize;
    data->s_last = data->s_base + newsize - 1;
    return 0;
}

#if YYPURE || defined(YY_NO_LEAKS)
static void yyfreestack(YYSTACKDATA *data)
{
    free(data->s_base);
    free(data->l_base);
    memset(data, 0, sizeof(*data));
}
#else
#define yyfreestack(data) /* nothing */
#endif

#define YYABORT  goto yyabort
#define YYREJECT goto yyabort
#define YYACCEPT goto yyaccept
#define YYERROR  goto yyerrlab

int
YYPARSE_DECL()
{
    int yym, yyn, yystate;
#if YYDEBUG
    const char *yys;

    if ((yys = getenv("YYDEBUG")) != 0)
    {
        yyn = *yys;
        if (yyn >= '0' && yyn <= '9')
            yydebug = yyn - '0';
    }
#endif

    yynerrs = 0;
    yyerrflag = 0;
    yychar = YYEMPTY;
    yystate = 0;

#if YYPURE
    memset(&yystack, 0, sizeof(yystack));
#endif

    if (yystack.s_base == NULL && yygrowstack(&yystack)) goto yyoverflow;
    yystack.s_mark = yystack.s_base;
    yystack.l_mark = yystack.l_base;
    yystate = 0;
    *yystack.s_mark = 0;

yyloop:
    if ((yyn = yydefred[yystate]) != 0) goto yyreduce;
    if (yychar < 0)
    {
        if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, reading %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
    }
    if ((yyn = yysindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: state %d, shifting to state %d\n",
                    YYPREFIX, yystate, yytable[yyn]);
#endif
        if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
        {
            goto yyoverflow;
        }
        yystate = yytable[yyn];
        *++yystack.s_mark = yytable[yyn];
        *++yystack.l_mark = yylval;
        yychar = YYEMPTY;
        if (yyerrflag > 0)  --yyerrflag;
        goto yyloop;
    }
    if ((yyn = yyrindex[yystate]) && (yyn += yychar) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yychar)
    {
        yyn = yytable[yyn];
        goto yyreduce;
    }
    if (yyerrflag) goto yyinrecovery;

    yyerror("syntax error");

    goto yyerrlab;

yyerrlab:
    ++yynerrs;

yyinrecovery:
    if (yyerrflag < 3)
    {
        yyerrflag = 3;
        for (;;)
        {
            if ((yyn = yysindex[*yystack.s_mark]) && (yyn += YYERRCODE) >= 0 &&
                    yyn <= YYTABLESIZE && yycheck[yyn] == YYERRCODE)
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: state %d, error recovery shifting\
 to state %d\n", YYPREFIX, *yystack.s_mark, yytable[yyn]);
#endif
                if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
                {
                    goto yyoverflow;
                }
                yystate = yytable[yyn];
                *++yystack.s_mark = yytable[yyn];
                *++yystack.l_mark = yylval;
                goto yyloop;
            }
            else
            {
#if YYDEBUG
                if (yydebug)
                    printf("%sdebug: error recovery discarding state %d\n",
                            YYPREFIX, *yystack.s_mark);
#endif
                if (yystack.s_mark <= yystack.s_base) goto yyabort;
                --yystack.s_mark;
                --yystack.l_mark;
            }
        }
    }
    else
    {
        if (yychar == 0) goto yyabort;
#if YYDEBUG
        if (yydebug)
        {
            yys = 0;
            if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
            if (!yys) yys = "illegal-symbol";
            printf("%sdebug: state %d, error recovery discards token %d (%s)\n",
                    YYPREFIX, yystate, yychar, yys);
        }
#endif
        yychar = YYEMPTY;
        goto yyloop;
    }

yyreduce:
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: state %d, reducing by rule %d (%s)\n",
                YYPREFIX, yystate, yyn, yyrule[yyn]);
#endif
    yym = yylen[yyn];
    if (yym)
        yyval = yystack.l_mark[1-yym];
    else
        memset(&yyval, 0, sizeof yyval);
    switch (yyn)
    {
case 26:
#line 448 "ircd_parser.y"
	{ yyval.number = 0; }
break;
case 28:
#line 450 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-1].number + yystack.l_mark[0].number;
		}
break;
case 29:
#line 454 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number + yystack.l_mark[0].number;
		}
break;
case 30:
#line 458 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 + yystack.l_mark[0].number;
		}
break;
case 31:
#line 462 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 * 60 + yystack.l_mark[0].number;
		}
break;
case 32:
#line 466 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 * 60 * 24 + yystack.l_mark[0].number;
		}
break;
case 33:
#line 470 "ircd_parser.y"
	{
			yyval.number = yystack.l_mark[-2].number * 60 * 60 * 24 * 7 + yystack.l_mark[0].number;
		}
break;
case 34:
#line 475 "ircd_parser.y"
	{ yyval.number = 0; }
break;
case 36:
#line 476 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-1].number + yystack.l_mark[0].number; }
break;
case 37:
#line 477 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-2].number + yystack.l_mark[0].number; }
break;
case 38:
#line 478 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-2].number * 1024 + yystack.l_mark[0].number; }
break;
case 39:
#line 479 "ircd_parser.y"
	{ yyval.number = yystack.l_mark[-2].number * 1024 * 1024 + yystack.l_mark[0].number; }
break;
case 46:
#line 493 "ircd_parser.y"
	{
#ifndef STATIC_MODULES /* NOOP in the static case */
  if (ypass == 2)
  {
    char *m_bn;

    m_bn = basename(yylval.string);

    /* I suppose we should just ignore it if it is already loaded(since
     * otherwise we would flood the opers on rehash) -A1kmm.
     */
    add_conf_module(yylval.string);
  }
#endif
}
break;
case 47:
#line 510 "ircd_parser.y"
	{
#ifndef STATIC_MODULES
  if (ypass == 2)
    mod_add_path(yylval.string);
#endif
}
break;
case 48:
#line 522 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(DNSBL_TYPE);
    yy_dconf = map_to_conf(yy_conf);
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 49:
#line 534 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_dconf->reason == NULL)
      delete_conf_item(yy_conf);
  }
}
break;
case 56:
#line 547 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 57:
#line 556 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_dconf->duration = yystack.l_mark[-1].number;
}
break;
case 58:
#line 562 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_dconf->reason);
    DupString(yy_dconf->reason, yylval.string);
  }
}
break;
case 76:
#line 587 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2 && ServerInfo.ctx) 
  {
    if (!ServerInfo.rsa_private_key_file)
    {
      yyerror("No rsa_private_key_file specified, SSL disabled");
      break;
    }

    if (SSL_CTX_use_certificate_chain_file(ServerInfo.ctx, yylval.string) <= 0)
    {
      yyerror(ERR_lib_error_string(ERR_get_error()));
      break;
    }

    if (SSL_CTX_use_PrivateKey_file(ServerInfo.ctx,
      ServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) <= 0)
    {
      yyerror(ERR_lib_error_string(ERR_get_error()));
      break;
    }

    if (!SSL_CTX_check_private_key(ServerInfo.ctx))
    {
      yyerror("RSA private key does not match the SSL certificate public key!");
      break;
    }
  }
#endif
}
break;
case 77:
#line 620 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2 && ServerInfo.ctx)
  {
    BIO *file = BIO_new_file(yylval.string, "r");

    if (file)
    {
      DH *dh = PEM_read_bio_DHparams(file, NULL, NULL, NULL);

      BIO_free(file);

      if (dh)
      {
        if (DH_size(dh) < 256)
        {
          yyerror("Ignoring ssl_dh_param_file -- need at least a 2048 bit DH prime size");
        }
        else
        {
          SSL_CTX_set_tmp_dh(ServerInfo.ctx, dh);
        }

        DH_free(dh);
      }
    }
  }
#endif
}
break;
case 78:
#line 651 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 1)
  {
    BIO *file;

    if (ServerInfo.rsa_private_key)
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;
    }

    if (ServerInfo.rsa_private_key_file)
    {
      MyFree(ServerInfo.rsa_private_key_file);
      ServerInfo.rsa_private_key_file = NULL;
    }

    DupString(ServerInfo.rsa_private_key_file, yylval.string);

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("File open failed, ignoring");
      break;
    }

    ServerInfo.rsa_private_key = (RSA *)PEM_read_bio_RSAPrivateKey(file, NULL,
      0, NULL);

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);

    if (ServerInfo.rsa_private_key == NULL)
    {
      yyerror("Couldn't extract key, ignoring");
      break;
    }

    if (!RSA_check_key(ServerInfo.rsa_private_key))
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;

      yyerror("Invalid key, ignoring");
      break;
    }

    if (RSA_size(ServerInfo.rsa_private_key) < 128)
    {
      RSA_free(ServerInfo.rsa_private_key);
      ServerInfo.rsa_private_key = NULL;

      yyerror("Ignoring rsa_private_key_file -- need at least a 1024 bit key size");
    }
  }
#endif
}
break;
case 79:
#line 710 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 1)
  {
    BIO *file;

    if (ServerInfo.cryptlink_private_key)
    {
      RSA_free(ServerInfo.cryptlink_private_key);
      ServerInfo.cryptlink_private_key = NULL;
    }

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("File open failed, ignoring");
      break;
    }

    ServerInfo.cryptlink_private_key = (RSA *)PEM_read_bio_RSAPrivateKey(file, NULL,
      0, NULL);

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);

    if (ServerInfo.cryptlink_private_key == NULL)
    {
      yyerror("Couldn't extract key, ignoring");
      break;
    }

    if (!RSA_check_key(ServerInfo.cryptlink_private_key))
    {
      RSA_free(ServerInfo.cryptlink_private_key);
      ServerInfo.cryptlink_private_key = NULL;

      yyerror("Invalid key, ignoring");
      break;
    }

    if (RSA_size(ServerInfo.cryptlink_private_key) < 128)
    {
      RSA_free(ServerInfo.cryptlink_private_key);
      ServerInfo.cryptlink_private_key = NULL;

      yyerror("Ignoring rsa_cryptlink_key_file -- need at least a 1024 bit key size");
    }
  }
#endif
}
break;
case 80:
#line 761 "ircd_parser.y"
	{
  /* this isn't rehashable */
  if (ypass == 2)
  {
    if (ServerInfo.name == NULL)
    {
      /* the ircd will exit() in main() if we dont set one */
      if (strlen(yylval.string) <= HOSTLEN)
        DupString(ServerInfo.name, yylval.string);
    }
  }
}
break;
case 81:
#line 775 "ircd_parser.y"
	{
  /* this isn't rehashable */
  if (ypass == 2 && !ServerInfo.sid)
  {
    if (valid_sid(yylval.string))
      DupString(ServerInfo.sid, yylval.string);
    else
    {
      ilog(L_ERROR, "Ignoring config file entry SID -- invalid SID. Aborting.");
      exit(0);
    }
  }
}
break;
case 82:
#line 790 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ServerInfo.description);
    DupString(ServerInfo.description,yylval.string);
  }
}
break;
case 83:
#line 799 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    char *p;

    if ((p = strchr(yylval.string, ' ')) != NULL)
      *p = '\0';

    MyFree(ServerInfo.network_name);
    DupString(ServerInfo.network_name, yylval.string);
  }
}
break;
case 84:
#line 813 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ServerInfo.network_desc);
    DupString(ServerInfo.network_desc, yylval.string);
  }
}
break;
case 85:
#line 822 "ircd_parser.y"
	{
  if (ypass == 2 && *yylval.string != '*')
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&ServerInfo.ip, res->ai_addr, res->ai_addrlen);
      ServerInfo.ip.ss.ss_family = res->ai_family;
      ServerInfo.ip.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);

      ServerInfo.specific_ipv4_vhost = 1;
    }
  }
}
break;
case 86:
#line 850 "ircd_parser.y"
	{
#ifdef IPV6
  if (ypass == 2 && *yylval.string != '*')
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost6(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&ServerInfo.ip6, res->ai_addr, res->ai_addrlen);
      ServerInfo.ip6.ss.ss_family = res->ai_family;
      ServerInfo.ip6.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);

      ServerInfo.specific_ipv6_vhost = 1;
    }
  }
#endif
}
break;
case 87:
#line 880 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    recalc_fdlimit(NULL);

    if (yystack.l_mark[-1].number < MAXCLIENTS_MIN)
    {
      char buf[IRCD_BUFSIZE];
      ircsprintf(buf, "MAXCLIENTS too low, setting to %d", MAXCLIENTS_MIN);
      yyerror(buf);
    }
    else if (yystack.l_mark[-1].number > MAXCLIENTS_MAX)
    {
      char buf[IRCD_BUFSIZE];
      ircsprintf(buf, "MAXCLIENTS too high, setting to %d", MAXCLIENTS_MAX);
      yyerror(buf);
    }
    else
      ServerInfo.max_clients = yystack.l_mark[-1].number;
  }
}
break;
case 88:
#line 903 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
    {
      /* Don't become a hub if we have a lazylink active. */
      if (!ServerInfo.hub && uplink && IsCapable(uplink, CAP_LL))
      {
        sendto_realops_flags(UMODE_ALL, L_ALL,
                             "Ignoring config file line hub=yes; "
                             "due to active LazyLink (%s)", uplink->name);
      }
      else
      {
        ServerInfo.hub = 1;
        uplink = NULL;
        delete_capability("HUB");
        add_capability("HUB", CAP_HUB, 1);
      }
    }
    else if (ServerInfo.hub)
    {
      dlink_node *ptr = NULL;

      ServerInfo.hub = 0;
      delete_capability("HUB");

      /* Don't become a leaf if we have a lazylink active. */
      DLINK_FOREACH(ptr, serv_list.head)
      {
        const struct Client *acptr = ptr->data;
        if (MyConnect(acptr) && IsCapable(acptr, CAP_LL))
        {
          sendto_realops_flags(UMODE_ALL, L_ALL,
                               "Ignoring config file line hub=no; "
                               "due to active LazyLink (%s)",
                               acptr->name);
          add_capability("HUB", CAP_HUB, 1);
          ServerInfo.hub = 1;
          break;
        }
      }
    }
  }
}
break;
case 96:
#line 959 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(AdminInfo.name);
    DupString(AdminInfo.name, yylval.string);
  }
}
break;
case 97:
#line 968 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(AdminInfo.email);
    DupString(AdminInfo.email, yylval.string);
  }
}
break;
case 98:
#line 977 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(AdminInfo.description);
    DupString(AdminInfo.description, yylval.string);
  }
}
break;
case 115:
#line 1004 "ircd_parser.y"
	{
                        }
break;
case 116:
#line 1008 "ircd_parser.y"
	{
                        }
break;
case 117:
#line 1012 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.userlog, yylval.string,
            sizeof(ConfigLoggingEntry.userlog));
}
break;
case 118:
#line 1019 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.failed_operlog, yylval.string,
            sizeof(ConfigLoggingEntry.failed_operlog));
}
break;
case 119:
#line 1026 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.operlog, yylval.string,
            sizeof(ConfigLoggingEntry.operlog));
}
break;
case 120:
#line 1033 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.operspylog, yylval.string,
            sizeof(ConfigLoggingEntry.operspylog));
}
break;
case 121:
#line 1040 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.glinelog, yylval.string,
            sizeof(ConfigLoggingEntry.glinelog));
}
break;
case 122:
#line 1047 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.klinelog, yylval.string,
            sizeof(ConfigLoggingEntry.klinelog));
}
break;
case 123:
#line 1054 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.ioerrlog, yylval.string,
            sizeof(ConfigLoggingEntry.ioerrlog));
}
break;
case 124:
#line 1061 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(ConfigLoggingEntry.killlog, yylval.string,
            sizeof(ConfigLoggingEntry.killlog));
}
break;
case 125:
#line 1068 "ircd_parser.y"
	{ 
  if (ypass == 2)
    set_log_level(L_CRIT);
}
break;
case 126:
#line 1072 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_ERROR);
}
break;
case 127:
#line 1076 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_WARN);
}
break;
case 128:
#line 1080 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_NOTICE);
}
break;
case 129:
#line 1084 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_TRACE);
}
break;
case 130:
#line 1088 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_INFO);
}
break;
case 131:
#line 1092 "ircd_parser.y"
	{
  if (ypass == 2)
    set_log_level(L_DEBUG);
}
break;
case 132:
#line 1098 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigLoggingEntry.use_logging = yylval.number;
}
break;
case 133:
#line 1107 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(OPER_TYPE);
    yy_aconf = map_to_conf(yy_conf);
    SetConfEncrypted(yy_aconf); /* Yes, the default is encrypted */
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 134:
#line 1120 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;
    dlink_node *ptr;
    dlink_node *next_ptr;

    if (yy_aconf->user && yy_aconf->host)
      conf_add_class_to_conf(yy_conf, class_name);
    else
      delete_conf_item(yy_conf);

    /* Now, make sure there is a copy of the "base" given oper
     * block in each of the collected copies
     */

    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;
      yy_tmp = ptr->data;

      new_conf = make_conf_item(OPER_TYPE);
      new_aconf = (struct AccessItem *)map_to_conf(new_conf);

      new_aconf->flags = yy_aconf->flags;

      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      if (yy_tmp->user != NULL)
	DupString(new_aconf->user, yy_tmp->user);
      else
	DupString(new_aconf->user, "*");
      if (yy_tmp->host != NULL)
	DupString(new_aconf->host, yy_tmp->host);
      else
	DupString(new_aconf->host, "*");
      conf_add_class_to_conf(new_conf, class_name);
      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);

      new_aconf->port = yy_aconf->port;
#ifdef HAVE_LIBCRYPTO
      if (yy_aconf->rsa_public_key_file != NULL)
      {
        BIO *file;

        DupString(new_aconf->rsa_public_key_file,
		  yy_aconf->rsa_public_key_file);

        file = BIO_new_file(yy_aconf->rsa_public_key_file, "r");
        new_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, 
							   NULL, 0, NULL);
        (void)BIO_set_close(file, BIO_CLOSE);
        BIO_free(file);
      }
      if (yy_aconf->certfp != NULL)
      {
        new_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
        memcpy(new_aconf->certfp, yy_aconf->certfp, SHA_DIGEST_LENGTH);
      }
#endif

#ifdef HAVE_LIBCRYPTO
      if (yy_tmp->name && (yy_tmp->passwd || yy_aconf->rsa_public_key)
	  && yy_tmp->host)
#else
      if (yy_tmp->name && yy_tmp->passwd && yy_tmp->host)
#endif
      {
        conf_add_class_to_conf(new_conf, class_name);
	if (yy_tmp->name != NULL)
	  DupString(new_conf->name, yy_tmp->name);
      }

      dlinkDelete(&yy_tmp->node, &col_conf_list);
      free_collect_item(yy_tmp);
    }

    yy_conf = NULL;
    yy_aconf = NULL;


    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 164:
#line 1220 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > OPERNICKLEN)
      yylval.string[OPERNICKLEN] = '\0';

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 165:
#line 1232 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > OPERNICKLEN)
      yylval.string[OPERNICKLEN] = '\0';

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 166:
#line 1244 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;
    
    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      struct CollectItem *yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 167:
#line 1278 "ircd_parser.y"
	{
  if (ypass == 2)
  {
#ifdef HAVE_LIBCRYPTO
    char tmp[SHA_DIGEST_LENGTH];
    
    if(yy_aconf->certfp != NULL)
    {
      MyFree(yy_aconf->certfp);
      yy_aconf->certfp = NULL;
    }

    if(base16_decode(tmp, SHA_DIGEST_LENGTH, yylval.string, strlen(yylval.string)) != 0)
    {
      yyerror("Invalid client certificate fingerprint provided. Ignoring");
      break;
    }
    yy_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->certfp, tmp, SHA_DIGEST_LENGTH);
#endif
  }
}
break;
case 168:
#line 1302 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_aconf->passwd != NULL)
      memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

    MyFree(yy_aconf->passwd);
    DupString(yy_aconf->passwd, yylval.string);
  }
}
break;
case 169:
#line 1314 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfEncrypted(yy_aconf);
    else
      ClearConfEncrypted(yy_aconf);
  }
}
break;
case 170:
#line 1325 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    BIO *file;

    if (yy_aconf->rsa_public_key != NULL)
    {
      RSA_free(yy_aconf->rsa_public_key);
      yy_aconf->rsa_public_key = NULL;
    }

    if (yy_aconf->rsa_public_key_file != NULL)
    {
      MyFree(yy_aconf->rsa_public_key_file);
      yy_aconf->rsa_public_key_file = NULL;
    }

    DupString(yy_aconf->rsa_public_key_file, yylval.string);
    file = BIO_new_file(yylval.string, "r");

    if (file == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- file doesn't exist");
      break;
    }

    yy_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, NULL, 0, NULL);

    if (yy_aconf->rsa_public_key == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- Key invalid; check key syntax.");
      break;
    }

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);
  }
#endif /* HAVE_LIBCRYPTO */
}
break;
case 171:
#line 1367 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 172:
#line 1376 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes = 0;
}
break;
case 176:
#line 1383 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_BOTS;
}
break;
case 177:
#line 1387 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_CCONN;
}
break;
case 178:
#line 1391 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_NOCTCP;
}
break;
case 179:
#line 1395 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_DEAF;
}
break;
case 180:
#line 1399 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_DEBUG;
}
break;
case 181:
#line 1403 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_FULL;
}
break;
case 182:
#line 1407 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SKILL;
}
break;
case 183:
#line 1411 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_NCHANGE;
}
break;
case 184:
#line 1415 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_REJ;
}
break;
case 185:
#line 1419 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_UNAUTH;
}
break;
case 186:
#line 1423 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SPY;
}
break;
case 187:
#line 1427 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_EXTERNAL;
}
break;
case 188:
#line 1431 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_OPERWALL;
}
break;
case 189:
#line 1435 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SERVNOTICE;
}
break;
case 190:
#line 1439 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_INVISIBLE;
}
break;
case 191:
#line 1443 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_WALLOP;
}
break;
case 192:
#line 1447 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_SOFTCALLERID;
}
break;
case 193:
#line 1451 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_CALLERID;
}
break;
case 194:
#line 1455 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_LOCOPS;
}
break;
case 195:
#line 1459 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_HIDECHANNELS;
}
break;
case 196:
#line 1463 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->modes |= UMODE_FARCONNECT;
}
break;
case 197:
#line 1469 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_GLOBAL_KILL;
    else
      yy_aconf->port &= ~OPER_FLAG_GLOBAL_KILL;
  }
}
break;
case 198:
#line 1480 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REMOTE;
    else
      yy_aconf->port &= ~OPER_FLAG_REMOTE; 
  }
}
break;
case 199:
#line 1491 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REMOTEBAN;
    else
      yy_aconf->port &= ~OPER_FLAG_REMOTEBAN;
  }
}
break;
case 200:
#line 1502 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_K;
    else
      yy_aconf->port &= ~OPER_FLAG_K;
  }
}
break;
case 201:
#line 1513 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_X;
    else
      yy_aconf->port &= ~OPER_FLAG_X;
  }
}
break;
case 202:
#line 1524 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_UNKLINE;
    else
      yy_aconf->port &= ~OPER_FLAG_UNKLINE; 
  }
}
break;
case 203:
#line 1535 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_GLINE;
    else
      yy_aconf->port &= ~OPER_FLAG_GLINE;
  }
}
break;
case 204:
#line 1546 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_N;
    else
      yy_aconf->port &= ~OPER_FLAG_N;
  }
}
break;
case 205:
#line 1557 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_DIE;
    else
      yy_aconf->port &= ~OPER_FLAG_DIE;
  }
}
break;
case 206:
#line 1568 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_REHASH;
    else
      yy_aconf->port &= ~OPER_FLAG_REHASH;
  }
}
break;
case 207:
#line 1579 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_ADMIN;
    else
      yy_aconf->port &= ~OPER_FLAG_ADMIN;
  }
}
break;
case 208:
#line 1590 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_HIDDEN_ADMIN;
    else
      yy_aconf->port &= ~OPER_FLAG_HIDDEN_ADMIN;
  }
}
break;
case 209:
#line 1601 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_HIDDEN_OPER;
    else
      yy_aconf->port &= ~OPER_FLAG_HIDDEN_OPER;
  }
}
break;
case 210:
#line 1612 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_OPER_SPY;
    else
      yy_aconf->port &= ~OPER_FLAG_OPER_SPY;
  }
}
break;
case 211:
#line 1623 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->port |= OPER_FLAG_OPERWALL;
    else
      yy_aconf->port &= ~OPER_FLAG_OPERWALL;
  }
}
break;
case 212:
#line 1634 "ircd_parser.y"
	{
}
break;
case 216:
#line 1638 "ircd_parser.y"
	{ not_atom = 1; }
break;
case 218:
#line 1639 "ircd_parser.y"
	{ not_atom = 0; }
break;
case 220:
#line 1642 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)yy_aconf->port &= ~OPER_FLAG_GLOBAL_KILL;
    else yy_aconf->port |= OPER_FLAG_GLOBAL_KILL;
  }
}
break;
case 221:
#line 1649 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REMOTE;
    else yy_aconf->port |= OPER_FLAG_REMOTE;
  }
}
break;
case 222:
#line 1656 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_K;
    else yy_aconf->port |= OPER_FLAG_K;
  }
}
break;
case 223:
#line 1663 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_UNKLINE;
    else yy_aconf->port |= OPER_FLAG_UNKLINE;
  } 
}
break;
case 224:
#line 1670 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_X;
    else yy_aconf->port |= OPER_FLAG_X;
  }
}
break;
case 225:
#line 1677 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_GLINE;
    else yy_aconf->port |= OPER_FLAG_GLINE;
  }
}
break;
case 226:
#line 1684 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_DIE;
    else yy_aconf->port |= OPER_FLAG_DIE;
  }
}
break;
case 227:
#line 1691 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REHASH;
    else yy_aconf->port |= OPER_FLAG_REHASH;
  }
}
break;
case 228:
#line 1698 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_ADMIN;
    else yy_aconf->port |= OPER_FLAG_ADMIN;
  }
}
break;
case 229:
#line 1705 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_HIDDEN_ADMIN;
    else yy_aconf->port |= OPER_FLAG_HIDDEN_ADMIN;
  }
}
break;
case 230:
#line 1712 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_N;
    else yy_aconf->port |= OPER_FLAG_N;
  }
}
break;
case 231:
#line 1719 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_OPERWALL;
    else yy_aconf->port |= OPER_FLAG_OPERWALL;
  }
}
break;
case 232:
#line 1726 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_OPER_SPY;
    else yy_aconf->port |= OPER_FLAG_OPER_SPY;
  }
}
break;
case 233:
#line 1733 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_HIDDEN_OPER;
    else yy_aconf->port |= OPER_FLAG_HIDDEN_OPER;
  }
}
break;
case 234:
#line 1740 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_REMOTEBAN;
    else yy_aconf->port |= OPER_FLAG_REMOTEBAN;
  }
}
break;
case 235:
#line 1747 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) ClearConfEncrypted(yy_aconf);
    else SetConfEncrypted(yy_aconf);
  }
}
break;
case 236:
#line 1754 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->port &= ~OPER_FLAG_FARCONNECT;
    else yy_aconf->port |= OPER_FLAG_FARCONNECT;
  }
}
break;
case 237:
#line 1767 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    yy_conf = make_conf_item(CLASS_TYPE);
    yy_class = map_to_conf(yy_conf);
  }
}
break;
case 238:
#line 1774 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    struct ConfItem *cconf = NULL;
    struct ClassItem *class = NULL;

    if (yy_class_name == NULL)
      delete_conf_item(yy_conf);
    else
    {
      cconf = find_exact_name_conf(CLASS_TYPE, yy_class_name, NULL, NULL, NULL);

      if (cconf != NULL)		/* The class existed already */
      {
        int user_count = 0;

        rebuild_cidr_class(cconf, yy_class);

        class = map_to_conf(cconf);

        user_count = class->curr_user_count;
        memcpy(class, yy_class, sizeof(*class));
        class->curr_user_count = user_count;
        class->active = 1;

        delete_conf_item(yy_conf);

        MyFree(cconf->name);            /* Allows case change of class name */
        cconf->name = yy_class_name;
      }
      else	/* Brand new class */
      {
        MyFree(yy_conf->name);          /* just in case it was allocated */
        yy_conf->name = yy_class_name;
	yy_class->active = 1;
      }
    }
    yy_class_name = NULL;
  }
}
break;
case 257:
#line 1833 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    MyFree(yy_class_name);
    DupString(yy_class_name, yylval.string);
  }
}
break;
case 258:
#line 1842 "ircd_parser.y"
	{
  if (ypass == 1)
  {
    MyFree(yy_class_name);
    DupString(yy_class_name, yylval.string);
  }
}
break;
case 259:
#line 1851 "ircd_parser.y"
	{
  if (ypass == 1)
    PingFreq(yy_class) = yystack.l_mark[-1].number;
}
break;
case 260:
#line 1857 "ircd_parser.y"
	{
  if (ypass == 1)
    PingWarning(yy_class) = yystack.l_mark[-1].number;
}
break;
case 261:
#line 1863 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxPerIp(yy_class) = yystack.l_mark[-1].number;
}
break;
case 262:
#line 1869 "ircd_parser.y"
	{
  if (ypass == 1)
    ConFreq(yy_class) = yystack.l_mark[-1].number;
}
break;
case 263:
#line 1875 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxTotal(yy_class) = yystack.l_mark[-1].number;
}
break;
case 264:
#line 1881 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxGlobal(yy_class) = yystack.l_mark[-1].number;
}
break;
case 265:
#line 1887 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxLocal(yy_class) = yystack.l_mark[-1].number;
}
break;
case 266:
#line 1893 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxIdent(yy_class) = yystack.l_mark[-1].number;
}
break;
case 267:
#line 1899 "ircd_parser.y"
	{
  if (ypass == 1)
    MaxSendq(yy_class) = yystack.l_mark[-1].number;
}
break;
case 268:
#line 1905 "ircd_parser.y"
	{
  if (ypass == 1)
    CidrBitlenIPV4(yy_class) = yystack.l_mark[-1].number;
}
break;
case 269:
#line 1911 "ircd_parser.y"
	{
  if (ypass == 1)
    CidrBitlenIPV6(yy_class) = yystack.l_mark[-1].number;
}
break;
case 270:
#line 1917 "ircd_parser.y"
	{
  if (ypass == 1)
    NumberPerCidr(yy_class) = yystack.l_mark[-1].number;
}
break;
case 271:
#line 1926 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    listener_address = NULL;
    listener_flags = 0;
  }
}
break;
case 272:
#line 1933 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(listener_address);
    listener_address = NULL;
  }
}
break;
case 273:
#line 1942 "ircd_parser.y"
	{
  listener_flags = 0;
}
break;
case 277:
#line 1948 "ircd_parser.y"
	{
  if (ypass == 2)
    listener_flags |= LISTENER_SSL;
}
break;
case 278:
#line 1952 "ircd_parser.y"
	{
  if (ypass == 2)
    listener_flags |= LISTENER_HIDDEN;
}
break;
case 286:
#line 1960 "ircd_parser.y"
	{ listener_flags = 0; }
break;
case 290:
#line 1965 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if ((listener_flags & LISTENER_SSL))
#ifdef HAVE_LIBCRYPTO
      if (!ServerInfo.ctx)
#endif
      {
        yyerror("SSL not available - port closed");
	break;
      }
    add_listener(yystack.l_mark[0].number, listener_address, listener_flags);
  }
}
break;
case 291:
#line 1979 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    int i;

    if ((listener_flags & LISTENER_SSL))
#ifdef HAVE_LIBCRYPTO
      if (!ServerInfo.ctx)
#endif
      {
        yyerror("SSL not available - port closed");
	break;
      }

    for (i = yystack.l_mark[-2].number; i <= yystack.l_mark[0].number; ++i)
      add_listener(i, listener_address, listener_flags);
  }
}
break;
case 292:
#line 1999 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(listener_address);
    DupString(listener_address, yylval.string);
  }
}
break;
case 293:
#line 2008 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(listener_address);
    DupString(listener_address, yylval.string);
  }
}
break;
case 294:
#line 2020 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(CLIENT_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 295:
#line 2032 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    dlink_node *ptr = NULL, *next_ptr = NULL;

    if (yy_aconf->user && yy_aconf->host)
    {
      conf_add_class_to_conf(yy_conf, class_name);
      add_conf_by_address(CONF_CLIENT, yy_aconf);
    }
    else
      delete_conf_item(yy_conf);

    /* copy over settings from first struct */
    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;

      new_conf = make_conf_item(CLIENT_TYPE);
      new_aconf = map_to_conf(new_conf);

      yy_tmp = ptr->data;

      assert(yy_tmp->user && yy_tmp->host);

      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);
      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      if (yy_aconf->passwd != NULL)
        DupString(new_aconf->passwd, yy_aconf->passwd);

      new_aconf->flags = yy_aconf->flags;
      new_aconf->port  = yy_aconf->port;

      DupString(new_aconf->user, yy_tmp->user);
      collapse(new_aconf->user);

      DupString(new_aconf->host, yy_tmp->host);
      collapse(new_aconf->host);

#ifdef HAVE_LIBCRYPTO
      if (yy_aconf->certfp != NULL)
      {
        new_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
        memcpy(new_aconf->certfp, yy_aconf->certfp, SHA_DIGEST_LENGTH);
      }
#endif

      conf_add_class_to_conf(new_conf, class_name);
      add_conf_by_address(CONF_CLIENT, new_aconf);
      dlinkDelete(&yy_tmp->node, &col_conf_list);
      free_collect_item(yy_tmp);
    }

    MyFree(class_name);
    class_name = NULL;
    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 317:
#line 2105 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 318:
#line 2142 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    /* be paranoid */
    if (yy_aconf->passwd != NULL)
      memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

    MyFree(yy_aconf->passwd);
    DupString(yy_aconf->passwd, yylval.string);
  }
}
break;
case 319:
#line 2155 "ircd_parser.y"
	{
  if (ypass == 2)
  {
#ifdef HAVE_LIBCRYPTO
    char tmp[SHA_DIGEST_LENGTH];

    if(yy_aconf->certfp != NULL)
    {
      MyFree(yy_aconf->certfp);
      yy_aconf->certfp = NULL;
    }

    if(base16_decode(tmp, SHA_DIGEST_LENGTH, yylval.string, strlen(yylval.string)) != 0)
    {
      yyerror("Invalid client certificate fingerprint provided. Ignoring");
      break;
    }
    yy_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->certfp, tmp, SHA_DIGEST_LENGTH);
#endif
  }
}
break;
case 320:
#line 2179 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_SPOOF_NOTICE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_SPOOF_NOTICE;
  }
}
break;
case 321:
#line 2190 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 322:
#line 2199 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfEncrypted(yy_aconf);
    else
      ClearConfEncrypted(yy_aconf);
  }
}
break;
case 323:
#line 2210 "ircd_parser.y"
	{
}
break;
case 327:
#line 2214 "ircd_parser.y"
	{ not_atom = 1; }
break;
case 329:
#line 2215 "ircd_parser.y"
	{ not_atom = 0; }
break;
case 331:
#line 2218 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_SPOOF_NOTICE;
    else yy_aconf->flags |= CONF_FLAGS_SPOOF_NOTICE;
  }

}
break;
case 332:
#line 2226 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NOLIMIT;
    else yy_aconf->flags |= CONF_FLAGS_NOLIMIT;
  }
}
break;
case 333:
#line 2233 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTKLINE;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTKLINE;
  } 
}
break;
case 334:
#line 2240 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NEED_IDENTD;
    else yy_aconf->flags |= CONF_FLAGS_NEED_IDENTD;
  }
}
break;
case 335:
#line 2247 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_CAN_FLOOD;
    else yy_aconf->flags |= CONF_FLAGS_CAN_FLOOD;
  }
}
break;
case 336:
#line 2254 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_IDLE_LINED;
    else yy_aconf->flags |= CONF_FLAGS_IDLE_LINED;
  }
}
break;
case 337:
#line 2261 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NO_TILDE;
    else yy_aconf->flags |= CONF_FLAGS_NO_TILDE;
  } 
}
break;
case 338:
#line 2268 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTGLINE;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTGLINE;
  } 
}
break;
case 339:
#line 2275 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_EXEMPTRESV;
    else yy_aconf->flags |= CONF_FLAGS_EXEMPTRESV;
  }
}
break;
case 340:
#line 2282 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_WEBIRC;
    else yy_aconf->flags |= CONF_FLAGS_WEBIRC;
  }
}
break;
case 341:
#line 2289 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom) yy_aconf->flags &= ~CONF_FLAGS_NEED_PASSWORD;
    else yy_aconf->flags |= CONF_FLAGS_NEED_PASSWORD;
  }
}
break;
case 342:
#line 2298 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_EXEMPTKLINE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_EXEMPTKLINE;
  }
}
break;
case 343:
#line 2309 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NEED_IDENTD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NEED_IDENTD;
  }
}
break;
case 344:
#line 2320 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NOLIMIT;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NOLIMIT;
  }
}
break;
case 345:
#line 2331 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_CAN_FLOOD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_CAN_FLOOD;
  }
}
break;
case 346:
#line 2342 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NO_TILDE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NO_TILDE;
  }
}
break;
case 347:
#line 2353 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_EXEMPTGLINE;
    else
      yy_aconf->flags &= ~CONF_FLAGS_EXEMPTGLINE;
  }
}
break;
case 348:
#line 2365 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);

    if (strlen(yylval.string) < HOSTLEN)
    {    
      DupString(yy_conf->name, yylval.string);
      yy_aconf->flags |= CONF_FLAGS_SPOOF_IP;
    }
    else
    {
      ilog(L_ERROR, "Spoofs must be less than %d..ignoring it", HOSTLEN);
      yy_conf->name = NULL;
    }
  }
}
break;
case 349:
#line 2384 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_aconf->flags |= CONF_FLAGS_REDIR;
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 350:
#line 2394 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_aconf->flags |= CONF_FLAGS_REDIR;
    yy_aconf->port = yystack.l_mark[-1].number;
  }
}
break;
case 351:
#line 2403 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_WEBIRC;
    else
      yy_aconf->flags &= ~CONF_FLAGS_WEBIRC;
  }
}
break;
case 352:
#line 2414 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_NEED_PASSWORD;
    else
      yy_aconf->flags &= ~CONF_FLAGS_NEED_PASSWORD;
  }
}
break;
case 353:
#line 2429 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    resv_reason = NULL;
  }
}
break;
case 354:
#line 2436 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    resv_reason = NULL;
  }
}
break;
case 361:
#line 2448 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(resv_reason);
    DupString(resv_reason, yylval.string);
  }
}
break;
case 362:
#line 2457 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (IsChanPrefix(*yylval.string))
    {
      char def_reason[] = "No reason";

      create_channel_resv(yylval.string, resv_reason != NULL ? resv_reason : def_reason, 1);
    }
  }
  /* ignore it for now.. but we really should make a warning if
   * its an erroneous name --fl_ */
}
break;
case 363:
#line 2472 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    char def_reason[] = "No reason";

    create_nick_resv(yylval.string, resv_reason != NULL ? resv_reason : def_reason, 1);
  }
}
break;
case 364:
#line 2485 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(ULINE_TYPE);
    yy_match_item = map_to_conf(yy_conf);
    yy_match_item->action = SHARED_ALL;
  }
}
break;
case 365:
#line 2493 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = NULL;
  }
}
break;
case 372:
#line 2504 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 373:
#line 2513 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    DupString(yy_match_item->user, userbuf);
    DupString(yy_match_item->host, hostbuf);
  }
}
break;
case 374:
#line 2535 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action = 0;
}
break;
case 378:
#line 2542 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_KLINE;
}
break;
case 379:
#line 2546 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TKLINE;
}
break;
case 380:
#line 2550 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNKLINE;
}
break;
case 381:
#line 2554 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_XLINE;
}
break;
case 382:
#line 2558 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TXLINE;
}
break;
case 383:
#line 2562 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNXLINE;
}
break;
case 384:
#line 2566 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_RESV;
}
break;
case 385:
#line 2570 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_TRESV;
}
break;
case 386:
#line 2574 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_UNRESV;
}
break;
case 387:
#line 2578 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_LOCOPS;
}
break;
case 388:
#line 2582 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_SERVICES;
}
break;
case 389:
#line 2586 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action |= SHARED_REHASH;
}
break;
case 390:
#line 2590 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_match_item->action = SHARED_ALL;
}
break;
case 391:
#line 2599 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(CLUSTER_TYPE);
    yy_conf->flags = SHARED_ALL;
  }
}
break;
case 392:
#line 2606 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_conf->name == NULL)
      DupString(yy_conf->name, "*");
    yy_conf = NULL;
  }
}
break;
case 398:
#line 2619 "ircd_parser.y"
	{
  if (ypass == 2)
    DupString(yy_conf->name, yylval.string);
}
break;
case 399:
#line 2625 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags = 0;
}
break;
case 403:
#line 2632 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_KLINE;
}
break;
case 404:
#line 2636 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TKLINE;
}
break;
case 405:
#line 2640 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNKLINE;
}
break;
case 406:
#line 2644 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_XLINE;
}
break;
case 407:
#line 2648 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TXLINE;
}
break;
case 408:
#line 2652 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNXLINE;
}
break;
case 409:
#line 2656 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_RESV;
}
break;
case 410:
#line 2660 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_TRESV;
}
break;
case 411:
#line 2664 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_UNRESV;
}
break;
case 412:
#line 2668 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags |= SHARED_LOCOPS;
}
break;
case 413:
#line 2672 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_conf->flags = SHARED_ALL;
}
break;
case 414:
#line 2681 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(SERVER_TYPE);
    yy_aconf = (struct AccessItem *)map_to_conf(yy_conf);
    yy_aconf->passwd = NULL;
    /* defaults */
    yy_aconf->port = PORTNUM;

    if (ConfigFileEntry.burst_away)
      yy_aconf->flags = CONF_FLAGS_BURST_AWAY;
  }
  else
  {
    MyFree(class_name);
    class_name = NULL;
  }
}
break;
case 415:
#line 2699 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_hconf=NULL;
    struct CollectItem *yy_lconf=NULL;
    dlink_node *ptr;
    dlink_node *next_ptr;
#ifdef HAVE_LIBCRYPTO
    if (yy_aconf->host &&
	((yy_aconf->passwd && yy_aconf->spasswd) ||
	 (yy_aconf->rsa_public_key && IsConfCryptLink(yy_aconf))))
#else /* !HAVE_LIBCRYPTO */
      if (yy_aconf->host && !IsConfCryptLink(yy_aconf) && 
	  yy_aconf->passwd && yy_aconf->spasswd)
#endif /* !HAVE_LIBCRYPTO */
	{
	  if (conf_add_server(yy_conf, class_name) == -1)
	  {
	    delete_conf_item(yy_conf);
	    yy_conf = NULL;
	    yy_aconf = NULL;
	  }
	}
	else
	{
	  /* Even if yy_conf ->name is NULL
	   * should still unhook any hub/leaf confs still pending
	   */
	  unhook_hub_leaf_confs();

	  if (yy_conf->name != NULL)
	  {
#ifndef HAVE_LIBCRYPTO
	    if (IsConfCryptLink(yy_aconf))
	      yyerror("Ignoring connect block -- no OpenSSL support");
#else
	    if (IsConfCryptLink(yy_aconf) && !yy_aconf->rsa_public_key)
	      yyerror("Ignoring connect block -- missing key");
#endif
	    if (yy_aconf->host == NULL)
	      yyerror("Ignoring connect block -- missing host");
	    else if (!IsConfCryptLink(yy_aconf) && 
		    (!yy_aconf->passwd || !yy_aconf->spasswd))
              yyerror("Ignoring connect block -- missing password");
	  }


          /* XXX
           * This fixes a try_connections() core (caused by invalid class_ptr
           * pointers) reported by metalrock. That's an ugly fix, but there
           * is currently no better way. The entire config subsystem needs an
           * rewrite ASAP. make_conf_item() shouldn't really add things onto
           * a doubly linked list immediately without any sanity checks!  -Michael
           */
          delete_conf_item(yy_conf);

          yy_aconf = NULL;
	  yy_conf = NULL;
	}

      /*
       * yy_conf is still pointing at the server that is having
       * a connect block built for it. This means, y_aconf->name 
       * points to the actual irc name this server will be known as.
       * Now this new server has a set or even just one hub_mask (or leaf_mask)
       * given in the link list at yy_hconf. Fill in the HUB confs
       * from this link list now.
       */        
      DLINK_FOREACH_SAFE(ptr, next_ptr, hub_conf_list.head)
      {
	struct ConfItem *new_hub_conf;
	struct MatchItem *match_item;

	yy_hconf = ptr->data;

	/* yy_conf == NULL is a fatal error for this connect block! */
	if ((yy_conf != NULL) && (yy_conf->name != NULL))
	{
	  new_hub_conf = make_conf_item(HUB_TYPE);
	  match_item = (struct MatchItem *)map_to_conf(new_hub_conf);
	  DupString(new_hub_conf->name, yy_conf->name);
	  if (yy_hconf->user != NULL)
	    DupString(match_item->user, yy_hconf->user);
	  else
	    DupString(match_item->user, "*");
	  if (yy_hconf->host != NULL)
	    DupString(match_item->host, yy_hconf->host);
	  else
	    DupString(match_item->host, "*");
	}
	dlinkDelete(&yy_hconf->node, &hub_conf_list);
	free_collect_item(yy_hconf);
      }

      /* Ditto for the LEAF confs */

      DLINK_FOREACH_SAFE(ptr, next_ptr, leaf_conf_list.head)
      {
	struct ConfItem *new_leaf_conf;
	struct MatchItem *match_item;

	yy_lconf = ptr->data;

	if ((yy_conf != NULL) && (yy_conf->name != NULL))
	{
	  new_leaf_conf = make_conf_item(LEAF_TYPE);
	  match_item = (struct MatchItem *)map_to_conf(new_leaf_conf);
	  DupString(new_leaf_conf->name, yy_conf->name);
	  if (yy_lconf->user != NULL)
	    DupString(match_item->user, yy_lconf->user);
	  else
	    DupString(match_item->user, "*");
	  if (yy_lconf->host != NULL)
	    DupString(match_item->host, yy_lconf->host);
	  else
	    DupString(match_item->host, "*");
	}
	dlinkDelete(&yy_lconf->node, &leaf_conf_list);
	free_collect_item(yy_lconf);
      }
      MyFree(class_name);
      class_name = NULL;
      yy_conf = NULL;
      yy_aconf = NULL;
  }
}
break;
case 440:
#line 2838 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_conf->name != NULL)
      yyerror("Multiple connect name entry");

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 441:
#line 2850 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_conf->name != NULL)
      yyerror("Multiple connect name entry");

    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 442:
#line 2862 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->host);
    DupString(yy_aconf->host, yylval.string);
  }
}
break;
case 443:
#line 2871 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct addrinfo hints, *res;

    memset(&hints, 0, sizeof(hints));

    hints.ai_family   = AF_UNSPEC;
    hints.ai_socktype = SOCK_STREAM;
    hints.ai_flags    = AI_PASSIVE | AI_NUMERICHOST;

    if (irc_getaddrinfo(yylval.string, NULL, &hints, &res))
      ilog(L_ERROR, "Invalid netmask for server vhost(%s)", yylval.string);
    else
    {
      assert(res != NULL);

      memcpy(&yy_aconf->my_ipnum, res->ai_addr, res->ai_addrlen);
      yy_aconf->my_ipnum.ss.ss_family = res->ai_family;
      yy_aconf->my_ipnum.ss_len = res->ai_addrlen;
      irc_freeaddrinfo(res);
    }
  }
}
break;
case 444:
#line 2897 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yystack.l_mark[-1].string[0] == ':')
      yyerror("Server passwords cannot begin with a colon");
    else if (strchr(yystack.l_mark[-1].string, ' ') != NULL)
      yyerror("Server passwords cannot contain spaces");
    else {
      if (yy_aconf->spasswd != NULL)
        memset(yy_aconf->spasswd, 0, strlen(yy_aconf->spasswd));

      MyFree(yy_aconf->spasswd);
      DupString(yy_aconf->spasswd, yylval.string);
    }
  }
}
break;
case 445:
#line 2915 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yystack.l_mark[-1].string[0] == ':')
      yyerror("Server passwords cannot begin with a colon");
    else if (strchr(yystack.l_mark[-1].string, ' ') != NULL)
      yyerror("Server passwords cannot contain spaces");
    else {
      if (yy_aconf->passwd != NULL)
        memset(yy_aconf->passwd, 0, strlen(yy_aconf->passwd));

      MyFree(yy_aconf->passwd);
      DupString(yy_aconf->passwd, yylval.string);
    }
  }
}
break;
case 446:
#line 2933 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->port = yystack.l_mark[-1].number;
}
break;
case 447:
#line 2939 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->aftype = AF_INET;
}
break;
case 448:
#line 2943 "ircd_parser.y"
	{
#ifdef IPV6
  if (ypass == 2)
    yy_aconf->aftype = AF_INET6;
#endif
}
break;
case 449:
#line 2951 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->fakename);
    DupString(yy_aconf->fakename, yylval.string);
  }
}
break;
case 450:
#line 2960 "ircd_parser.y"
	{
}
break;
case 454:
#line 2964 "ircd_parser.y"
	{ not_atom = 1; }
break;
case 456:
#line 2965 "ircd_parser.y"
	{ not_atom = 0; }
break;
case 458:
#line 2968 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfLazyLink(yy_aconf);
    else SetConfLazyLink(yy_aconf);
  }
}
break;
case 459:
#line 2975 "ircd_parser.y"
	{
  if (ypass == 2)
#ifndef HAVE_LIBZ
    yyerror("Ignoring flags = compressed; -- no zlib support");
#else
 {
   if (not_atom)ClearConfCompressed(yy_aconf);
   else SetConfCompressed(yy_aconf);
 }
#endif
}
break;
case 460:
#line 2986 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfCryptLink(yy_aconf);
    else SetConfCryptLink(yy_aconf);
  }
}
break;
case 461:
#line 2993 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfAllowAutoConn(yy_aconf);
    else SetConfAllowAutoConn(yy_aconf);
  }
}
break;
case 462:
#line 3000 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfAwayBurst(yy_aconf);
    else SetConfAwayBurst(yy_aconf);
  }
}
break;
case 463:
#line 3007 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (not_atom)ClearConfTopicBurst(yy_aconf);
    else SetConfTopicBurst(yy_aconf);
  }
}
break;
case 464:
#line 3017 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    BIO *file;

    if (yy_aconf->rsa_public_key != NULL)
    {
      RSA_free(yy_aconf->rsa_public_key);
      yy_aconf->rsa_public_key = NULL;
    }

    if (yy_aconf->rsa_public_key_file != NULL)
    {
      MyFree(yy_aconf->rsa_public_key_file);
      yy_aconf->rsa_public_key_file = NULL;
    }

    DupString(yy_aconf->rsa_public_key_file, yylval.string);

    if ((file = BIO_new_file(yylval.string, "r")) == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- file doesn't exist");
      break;
    }

    yy_aconf->rsa_public_key = (RSA *)PEM_read_bio_RSA_PUBKEY(file, NULL, 0, NULL);

    if (yy_aconf->rsa_public_key == NULL)
    {
      yyerror("Ignoring rsa_public_key_file -- Key invalid; check key syntax.");
      break;
    }

    (void)BIO_set_close(file, BIO_CLOSE);
    BIO_free(file);
  }
#endif /* HAVE_LIBCRYPTO */
}
break;
case 465:
#line 3058 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_ENCRYPTED;
    else
      yy_aconf->flags &= ~CONF_FLAGS_ENCRYPTED;
  }
}
break;
case 466:
#line 3069 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_CRYPTLINK;
    else
      yy_aconf->flags &= ~CONF_FLAGS_CRYPTLINK;
  }
}
break;
case 467:
#line 3080 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
#ifndef HAVE_LIBZ
      yyerror("Ignoring compressed=yes; -- no zlib support");
#else
      yy_aconf->flags |= CONF_FLAGS_COMPRESSED;
#endif
    else
      yy_aconf->flags &= ~CONF_FLAGS_COMPRESSED;
  }
}
break;
case 468:
#line 3095 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      yy_aconf->flags |= CONF_FLAGS_ALLOW_AUTO_CONN;
    else
      yy_aconf->flags &= ~CONF_FLAGS_ALLOW_AUTO_CONN;
  }
}
break;
case 469:
#line 3106 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.number)
      SetConfTopicBurst(yy_aconf);
    else
      ClearConfTopicBurst(yy_aconf);
  }
}
break;
case 470:
#line 3117 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;

    yy_tmp = (struct CollectItem *)MyMalloc(sizeof(struct CollectItem));
    DupString(yy_tmp->host, yylval.string);
    DupString(yy_tmp->user, "*");
    dlinkAdd(yy_tmp, &yy_tmp->node, &hub_conf_list);
  }
}
break;
case 471:
#line 3130 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp;

    yy_tmp = (struct CollectItem *)MyMalloc(sizeof(struct CollectItem));
    DupString(yy_tmp->host, yylval.string);
    DupString(yy_tmp->user, "*");
    dlinkAdd(yy_tmp, &yy_tmp->node, &leaf_conf_list);
  }
}
break;
case 472:
#line 3143 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(class_name);
    DupString(class_name, yylval.string);
  }
}
break;
case 473:
#line 3152 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    struct EncCapability *ecap;
    const char *cipher_name;
    int found = 0;

    yy_aconf->cipher_preference = NULL;
    cipher_name = yylval.string;

    for (ecap = CipherTable; ecap->name; ecap++)
    {
      if ((irccmp(ecap->name, cipher_name) == 0) &&
          (ecap->cap & CAP_ENC_MASK))
      {
        yy_aconf->cipher_preference = ecap;
        found = 1;
        break;
      }
    }

    if (!found)
      yyerror("Invalid cipher");
  }
#else
  if (ypass == 2)
    yyerror("Ignoring cipher_preference -- no OpenSSL support");
#endif
}
break;
case 474:
#line 3187 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    userbuf[0] = hostbuf[0] = reasonbuf[0] = '\0';
    regex_ban = 0;
  }
}
break;
case 475:
#line 3194 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (userbuf[0] && hostbuf[0])
    {
      if (regex_ban)
      {
        pcre *exp_user = NULL;
        pcre *exp_host = NULL;
        const char *errptr = NULL;

        if (!(exp_user = ircd_pcre_compile(userbuf, &errptr)) ||
            !(exp_host = ircd_pcre_compile(hostbuf, &errptr)))
        {
          ilog(L_ERROR, "Failed to add regular expression based K-Line: %s", errptr);
          break;
        }

        yy_conf = make_conf_item(RKLINE_TYPE);
	yy_aconf = map_to_conf(yy_conf);

        yy_aconf->regexuser = exp_user;
        yy_aconf->regexhost = exp_host;

        DupString(yy_aconf->user, userbuf);
        DupString(yy_aconf->host, hostbuf);

        if (reasonbuf[0])
          DupString(yy_aconf->reason, reasonbuf);
        else
          DupString(yy_aconf->reason, "No reason");
      }
      else
      {
        yy_conf = make_conf_item(KLINE_TYPE);
        yy_aconf = map_to_conf(yy_conf);

        DupString(yy_aconf->user, userbuf);
        DupString(yy_aconf->host, hostbuf);

        if (reasonbuf[0])
          DupString(yy_aconf->reason, reasonbuf);
        else
          DupString(yy_aconf->reason, "No reason");
        add_conf_by_address(CONF_KILL, yy_aconf);
      }
    }
    else
      delete_conf_item(yy_conf);

    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 476:
#line 3250 "ircd_parser.y"
	{
}
break;
case 480:
#line 3255 "ircd_parser.y"
	{
  if (ypass == 2)
    regex_ban = 1;
}
break;
case 487:
#line 3264 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);
  }
}
break;
case 488:
#line 3283 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(reasonbuf, yylval.string, sizeof(reasonbuf));
}
break;
case 489:
#line 3292 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(DLINE_TYPE);
    yy_aconf = map_to_conf(yy_conf);
    /* default reason */
    DupString(yy_aconf->reason, "No reason");
  }
}
break;
case 490:
#line 3301 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yy_aconf->host && parse_netmask(yy_aconf->host, NULL, NULL) != HM_HOST)
      add_conf_by_address(CONF_DLINE, yy_aconf);
    else
      delete_conf_item(yy_conf);
    yy_conf = NULL;
    yy_aconf = NULL;
  }
}
break;
case 496:
#line 3317 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->host);
    DupString(yy_aconf->host, yylval.string);
  }
}
break;
case 497:
#line 3326 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(yy_aconf->reason);
    DupString(yy_aconf->reason, yylval.string);
  }
}
break;
case 504:
#line 3343 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (yylval.string[0] && parse_netmask(yylval.string, NULL, NULL) != HM_HOST)
    {
      yy_conf = make_conf_item(EXEMPTDLINE_TYPE);
      yy_aconf = map_to_conf(yy_conf);
      DupString(yy_aconf->host, yylval.string);

      add_conf_by_address(CONF_EXEMPTDLINE, yy_aconf);

      yy_conf = NULL;
      yy_aconf = NULL;
    }
  }
}
break;
case 505:
#line 3361 "ircd_parser.y"
	{
  if (ypass == 2)
  {
#ifdef HAVE_LIBCRYPTO
    char tmp[SHA_DIGEST_LENGTH];

    yy_conf = make_conf_item(EXEMPTDLINE_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  
    if(base16_decode(tmp, SHA_DIGEST_LENGTH, yylval.string, strlen(yylval.string)) != 0)
    {
      yyerror("Invalid client certificate fingerprint provided. Ignoring");
      break;
    }
 
    yy_aconf->certfp = MyMalloc(SHA_DIGEST_LENGTH);
    yy_aconf->host = MyMalloc(SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->certfp, tmp, SHA_DIGEST_LENGTH);
    memcpy(yy_aconf->host, tmp, SHA_DIGEST_LENGTH);
 
    add_conf_by_address(CONF_EXEMPTDLINE, yy_aconf);

    yy_conf = NULL;
    yy_aconf = NULL;
#endif
 }
}
break;
case 506:
#line 3394 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    regex_ban = 0;
    reasonbuf[0] = gecos_name[0] = '\0';
  }
}
break;
case 507:
#line 3401 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (gecos_name[0])
    {
      if (regex_ban)
      {
        pcre *exp_p = NULL;
        const char *errptr = NULL;

        if (!(exp_p = ircd_pcre_compile(gecos_name, &errptr)))
        {
          ilog(L_ERROR, "Failed to add regular expression based X-Line: %s", errptr);
          break;
        }

        yy_conf = make_conf_item(RXLINE_TYPE);
        yy_conf->regexpname = exp_p;
      }
      else
        yy_conf = make_conf_item(XLINE_TYPE);

      yy_match_item = map_to_conf(yy_conf);
      DupString(yy_conf->name, gecos_name);

      if (reasonbuf[0])
        DupString(yy_match_item->reason, reasonbuf);
      else
        DupString(yy_match_item->reason, "No reason");
    }
  }
}
break;
case 508:
#line 3435 "ircd_parser.y"
	{
}
break;
case 512:
#line 3440 "ircd_parser.y"
	{
  if (ypass == 2)
    regex_ban = 1;
}
break;
case 519:
#line 3449 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(gecos_name, yylval.string, sizeof(gecos_name));
}
break;
case 520:
#line 3455 "ircd_parser.y"
	{
  if (ypass == 2)
    strlcpy(reasonbuf, yylval.string, sizeof(reasonbuf));
}
break;
case 590:
#line 3504 "ircd_parser.y"
	{
  ConfigFileEntry.gline_min_cidr = yystack.l_mark[-1].number;
}
break;
case 591:
#line 3509 "ircd_parser.y"
	{
  ConfigFileEntry.gline_min_cidr6 = yystack.l_mark[-1].number;
}
break;
case 592:
#line 3514 "ircd_parser.y"
	{
  ConfigFileEntry.burst_away = yylval.number;
}
break;
case 593:
#line 3519 "ircd_parser.y"
	{
  ConfigFileEntry.use_whois_actually = yylval.number;
}
break;
case 594:
#line 3524 "ircd_parser.y"
	{
  ConfigFileEntry.nick_collide_realhost = yylval.number;
}
break;
case 595:
#line 3529 "ircd_parser.y"
	{
  GlobalSetOptions.rejecttime = yylval.number;
}
break;
case 596:
#line 3534 "ircd_parser.y"
	{
  ConfigFileEntry.tkline_expire_notices = yylval.number;
}
break;
case 597:
#line 3539 "ircd_parser.y"
	{
  ConfigFileEntry.kill_chase_time_limit = yystack.l_mark[-1].number;
}
break;
case 598:
#line 3544 "ircd_parser.y"
	{
  ConfigFileEntry.hide_spoof_ips = yylval.number;
}
break;
case 599:
#line 3549 "ircd_parser.y"
	{
  ConfigFileEntry.ignore_bogus_ts = yylval.number;
}
break;
case 600:
#line 3554 "ircd_parser.y"
	{
  ConfigFileEntry.disable_remote = yylval.number;
}
break;
case 601:
#line 3559 "ircd_parser.y"
	{
  ConfigFileEntry.failed_oper_notice = yylval.number;
}
break;
case 602:
#line 3564 "ircd_parser.y"
	{
  ConfigFileEntry.anti_nick_flood = yylval.number;
}
break;
case 603:
#line 3569 "ircd_parser.y"
	{
  ConfigFileEntry.max_nick_time = yystack.l_mark[-1].number; 
}
break;
case 604:
#line 3574 "ircd_parser.y"
	{
  ConfigFileEntry.max_nick_changes = yystack.l_mark[-1].number;
}
break;
case 605:
#line 3579 "ircd_parser.y"
	{
  ConfigFileEntry.max_accept = yystack.l_mark[-1].number;
}
break;
case 606:
#line 3584 "ircd_parser.y"
	{
  ConfigFileEntry.anti_spam_exit_message_time = yystack.l_mark[-1].number;
}
break;
case 607:
#line 3589 "ircd_parser.y"
	{
  ConfigFileEntry.anti_spam_connect_numeric = yylval.number;
}
break;
case 608:
#line 3594 "ircd_parser.y"
	{
  ConfigFileEntry.ts_warn_delta = yystack.l_mark[-1].number;
}
break;
case 609:
#line 3599 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.ts_max_delta = yystack.l_mark[-1].number;
}
break;
case 610:
#line 3605 "ircd_parser.y"
	{
  if ((yystack.l_mark[-1].number > 0) && ypass == 1)
  {
    ilog(L_CRIT, "You haven't read your config file properly.");
    ilog(L_CRIT, "There is a line in the example conf that will kill your server if not removed.");
    ilog(L_CRIT, "Consider actually reading/editing the conf file, and removing this line.");
    exit(0);
  }
}
break;
case 611:
#line 3616 "ircd_parser.y"
	{
  ConfigFileEntry.kline_with_reason = yylval.number;
}
break;
case 612:
#line 3621 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.kline_reason);
    DupString(ConfigFileEntry.kline_reason, yylval.string);
  }
}
break;
case 613:
#line 3630 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.cloak_key1);
    DupString(ConfigFileEntry.cloak_key1, yylval.string);
  }
}
break;
case 614:
#line 3639 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.cloak_key2);
    DupString(ConfigFileEntry.cloak_key2, yylval.string);
  }
}
break;
case 615:
#line 3648 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.cloak_key3);
    DupString(ConfigFileEntry.cloak_key3, yylval.string);
  }
}
break;
case 616:
#line 3657 "ircd_parser.y"
	{
  ConfigFileEntry.cloak_whois_actually = yylval.number;
}
break;
case 617:
#line 3662 "ircd_parser.y"
	{
  ConfigFileEntry.account_whois = yylval.number;
}
break;
case 618:
#line 3667 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.services_name);
    DupString(ConfigFileEntry.services_name, yylval.string);
  }
}
break;
case 619:
#line 3676 "ircd_parser.y"
	{
  ConfigFileEntry.invisible_on_connect = yylval.number;
}
break;
case 620:
#line 3681 "ircd_parser.y"
	{
  ConfigFileEntry.warn_no_nline = yylval.number;
}
break;
case 621:
#line 3686 "ircd_parser.y"
	{
  ConfigFileEntry.stats_e_disabled = yylval.number;
}
break;
case 622:
#line 3691 "ircd_parser.y"
	{
  ConfigFileEntry.stats_o_oper_only = yylval.number;
}
break;
case 623:
#line 3696 "ircd_parser.y"
	{
  ConfigFileEntry.stats_P_oper_only = yylval.number;
}
break;
case 624:
#line 3701 "ircd_parser.y"
	{
  ConfigFileEntry.hide_killer = yylval.number;
}
break;
case 625:
#line 3706 "ircd_parser.y"
	{
  ConfigFileEntry.stats_k_oper_only = 2 * yylval.number;
}
break;
case 626:
#line 3709 "ircd_parser.y"
	{
  ConfigFileEntry.stats_k_oper_only = 1;
}
break;
case 627:
#line 3714 "ircd_parser.y"
	{
  ConfigFileEntry.stats_i_oper_only = 2 * yylval.number;
}
break;
case 628:
#line 3717 "ircd_parser.y"
	{
  ConfigFileEntry.stats_i_oper_only = 1;
}
break;
case 629:
#line 3722 "ircd_parser.y"
	{
  ConfigFileEntry.pace_wait = yystack.l_mark[-1].number;
}
break;
case 630:
#line 3727 "ircd_parser.y"
	{
  ConfigFileEntry.caller_id_wait = yystack.l_mark[-1].number;
}
break;
case 631:
#line 3732 "ircd_parser.y"
	{
  ConfigFileEntry.opers_bypass_callerid = yylval.number;
}
break;
case 632:
#line 3737 "ircd_parser.y"
	{
  ConfigFileEntry.pace_wait_simple = yystack.l_mark[-1].number;
}
break;
case 633:
#line 3742 "ircd_parser.y"
	{
  ConfigFileEntry.short_motd = yylval.number;
}
break;
case 634:
#line 3747 "ircd_parser.y"
	{
  ConfigFileEntry.no_oper_flood = yylval.number;
}
break;
case 635:
#line 3752 "ircd_parser.y"
	{
  ConfigFileEntry.true_no_oper_flood = yylval.number;
}
break;
case 636:
#line 3757 "ircd_parser.y"
	{
  ConfigFileEntry.oper_pass_resv = yylval.number;
}
break;
case 637:
#line 3762 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if (strlen(yylval.string) > LOCALE_LENGTH-2)
      yylval.string[LOCALE_LENGTH-1] = '\0';

    set_locale(yylval.string);
  }
}
break;
case 638:
#line 3773 "ircd_parser.y"
	{
  ConfigFileEntry.idletime = yystack.l_mark[-1].number;
}
break;
case 639:
#line 3778 "ircd_parser.y"
	{
  ConfigFileEntry.dots_in_ident = yystack.l_mark[-1].number;
}
break;
case 640:
#line 3783 "ircd_parser.y"
	{
  ConfigFileEntry.max_targets = yystack.l_mark[-1].number;
}
break;
case 641:
#line 3788 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.servlink_path);
    DupString(ConfigFileEntry.servlink_path, yylval.string);
  }
}
break;
case 642:
#line 3797 "ircd_parser.y"
	{
#ifdef HAVE_LIBCRYPTO
  if (ypass == 2)
  {
    struct EncCapability *ecap;
    const char *cipher_name;
    int found = 0;

    ConfigFileEntry.default_cipher_preference = NULL;
    cipher_name = yylval.string;

    for (ecap = CipherTable; ecap->name; ecap++)
    {
      if ((irccmp(ecap->name, cipher_name) == 0) &&
          (ecap->cap & CAP_ENC_MASK))
      {
        ConfigFileEntry.default_cipher_preference = ecap;
        found = 1;
        break;
      }
    }

    if (!found)
      yyerror("Invalid cipher");
  }
#else
  if (ypass == 2)
    yyerror("Ignoring default_cipher_preference -- no OpenSSL support");
#endif
}
break;
case 643:
#line 3829 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    ConfigFileEntry.compression_level = yystack.l_mark[-1].number;
#ifndef HAVE_LIBZ
    yyerror("Ignoring compression_level -- no zlib support");
#else
    if ((ConfigFileEntry.compression_level < 1) ||
        (ConfigFileEntry.compression_level > 9))
    {
      yyerror("Ignoring invalid compression_level, using default");
      ConfigFileEntry.compression_level = 0;
    }
#endif
  }
}
break;
case 644:
#line 3847 "ircd_parser.y"
	{
  ConfigFileEntry.use_egd = yylval.number;
}
break;
case 645:
#line 3852 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigFileEntry.egdpool_path);
    DupString(ConfigFileEntry.egdpool_path, yylval.string);
  }
}
break;
case 646:
#line 3861 "ircd_parser.y"
	{
  ConfigFileEntry.ping_cookie = yylval.number;
}
break;
case 647:
#line 3866 "ircd_parser.y"
	{
  ConfigFileEntry.disable_auth = yylval.number;
}
break;
case 648:
#line 3871 "ircd_parser.y"
	{
  ConfigFileEntry.throttle_num = yylval.number;
}
break;
case 649:
#line 3876 "ircd_parser.y"
	{
  ConfigFileEntry.throttle_time = yylval.number;
}
break;
case 650:
#line 3881 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes = 0;
}
break;
case 654:
#line 3887 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_BOTS;
}
break;
case 655:
#line 3890 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_CCONN;
}
break;
case 656:
#line 3893 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_NOCTCP;
}
break;
case 657:
#line 3896 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_DEAF;
}
break;
case 658:
#line 3899 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_DEBUG;
}
break;
case 659:
#line 3902 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_FULL;
}
break;
case 660:
#line 3905 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SKILL;
}
break;
case 661:
#line 3908 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_NCHANGE;
}
break;
case 662:
#line 3911 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_REJ;
}
break;
case 663:
#line 3914 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_UNAUTH;
}
break;
case 664:
#line 3917 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SPY;
}
break;
case 665:
#line 3920 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_EXTERNAL;
}
break;
case 666:
#line 3923 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_OPERWALL;
}
break;
case 667:
#line 3926 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SERVNOTICE;
}
break;
case 668:
#line 3929 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_INVISIBLE;
}
break;
case 669:
#line 3932 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_WALLOP;
}
break;
case 670:
#line 3935 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_SOFTCALLERID;
}
break;
case 671:
#line 3938 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_CALLERID;
}
break;
case 672:
#line 3941 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_LOCOPS;
}
break;
case 673:
#line 3944 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_HIDECHANNELS;
}
break;
case 674:
#line 3947 "ircd_parser.y"
	{
  ConfigFileEntry.oper_umodes |= UMODE_FARCONNECT;
}
break;
case 675:
#line 3952 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes = 0;
}
break;
case 679:
#line 3958 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_BOTS;
}
break;
case 680:
#line 3961 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_CCONN;
}
break;
case 681:
#line 3964 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_NOCTCP;
}
break;
case 682:
#line 3967 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_DEAF;
}
break;
case 683:
#line 3970 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_DEBUG;
}
break;
case 684:
#line 3973 "ircd_parser.y"
	{ 
  ConfigFileEntry.oper_only_umodes |= UMODE_FULL;
}
break;
case 685:
#line 3976 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SKILL;
}
break;
case 686:
#line 3979 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_NCHANGE;
}
break;
case 687:
#line 3982 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_REJ;
}
break;
case 688:
#line 3985 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_UNAUTH;
}
break;
case 689:
#line 3988 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SPY;
}
break;
case 690:
#line 3991 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_EXTERNAL;
}
break;
case 691:
#line 3994 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_OPERWALL;
}
break;
case 692:
#line 3997 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SERVNOTICE;
}
break;
case 693:
#line 4000 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_INVISIBLE;
}
break;
case 694:
#line 4003 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_WALLOP;
}
break;
case 695:
#line 4006 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_SOFTCALLERID;
}
break;
case 696:
#line 4009 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_CALLERID;
}
break;
case 697:
#line 4012 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_LOCOPS;
}
break;
case 698:
#line 4015 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_HIDECHANNELS;
}
break;
case 699:
#line 4018 "ircd_parser.y"
	{
  ConfigFileEntry.oper_only_umodes |= UMODE_FARCONNECT;
}
break;
case 700:
#line 4023 "ircd_parser.y"
	{
  ConfigFileEntry.min_nonwildcard = yystack.l_mark[-1].number;
}
break;
case 701:
#line 4028 "ircd_parser.y"
	{
  ConfigFileEntry.min_nonwildcard_simple = yystack.l_mark[-1].number;
}
break;
case 702:
#line 4033 "ircd_parser.y"
	{
  ConfigFileEntry.default_floodcount = yystack.l_mark[-1].number;
}
break;
case 703:
#line 4038 "ircd_parser.y"
	{
  ConfigFileEntry.client_flood = yystack.l_mark[-1].number;
}
break;
case 704:
#line 4043 "ircd_parser.y"
	{
  ConfigFileEntry.dot_in_ip6_addr = yylval.number;
}
break;
case 705:
#line 4051 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    yy_conf = make_conf_item(GDENY_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
}
break;
case 706:
#line 4058 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    /*
     * since we re-allocate yy_conf/yy_aconf after the end of action=, at the
     * end we will have one extra, so we should free it.
     */
    if (yy_conf->name == NULL || yy_aconf->user == NULL)
    {
      delete_conf_item(yy_conf);
      yy_conf = NULL;
      yy_aconf = NULL;
    }
  }
}
break;
case 716:
#line 4084 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.glines = yylval.number;
}
break;
case 717:
#line 4090 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_time = yystack.l_mark[-1].number;
}
break;
case 718:
#line 4096 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_logging = 0;
}
break;
case 722:
#line 4102 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_logging |= GDENY_REJECT;
}
break;
case 723:
#line 4106 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigFileEntry.gline_logging |= GDENY_BLOCK;
}
break;
case 724:
#line 4112 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct split_nuh_item nuh;

    nuh.nuhmask  = yylval.string;
    nuh.nickptr  = NULL;
    nuh.userptr  = userbuf;
    nuh.hostptr  = hostbuf;

    nuh.nicksize = 0;
    nuh.usersize = sizeof(userbuf);
    nuh.hostsize = sizeof(hostbuf);

    split_nuh(&nuh);

    if (yy_aconf->user == NULL)
    {
      DupString(yy_aconf->user, userbuf);
      DupString(yy_aconf->host, hostbuf);
    }
    else
    {
      struct CollectItem *yy_tmp = MyMalloc(sizeof(struct CollectItem));

      DupString(yy_tmp->user, userbuf);
      DupString(yy_tmp->host, hostbuf);

      dlinkAdd(yy_tmp, &yy_tmp->node, &col_conf_list);
    }
  }
}
break;
case 725:
#line 4146 "ircd_parser.y"
	{
  if (ypass == 2)  
  {
    MyFree(yy_conf->name);
    DupString(yy_conf->name, yylval.string);
  }
}
break;
case 726:
#line 4155 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->flags = 0;
}
break;
case 727:
#line 4159 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    struct CollectItem *yy_tmp = NULL;
    dlink_node *ptr, *next_ptr;

    DLINK_FOREACH_SAFE(ptr, next_ptr, col_conf_list.head)
    {
      struct AccessItem *new_aconf;
      struct ConfItem *new_conf;

      yy_tmp = ptr->data;
      new_conf = make_conf_item(GDENY_TYPE);
      new_aconf = map_to_conf(new_conf);

      new_aconf->flags = yy_aconf->flags;

      if (yy_conf->name != NULL)
        DupString(new_conf->name, yy_conf->name);
      else
        DupString(new_conf->name, "*");
      if (yy_aconf->user != NULL)
         DupString(new_aconf->user, yy_tmp->user);
      else   
        DupString(new_aconf->user, "*");
      if (yy_aconf->host != NULL)
        DupString(new_aconf->host, yy_tmp->host);
      else
        DupString(new_aconf->host, "*");

      dlinkDelete(&yy_tmp->node, &col_conf_list);
    }

    /*
     * In case someone has fed us with more than one action= after user/name
     * which would leak memory  -Michael
     */
    if (yy_conf->name == NULL || yy_aconf->user == NULL)
      delete_conf_item(yy_conf);

    yy_conf = make_conf_item(GDENY_TYPE);
    yy_aconf = map_to_conf(yy_conf);
  }
}
break;
case 730:
#line 4206 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->flags |= GDENY_REJECT;
}
break;
case 731:
#line 4210 "ircd_parser.y"
	{
  if (ypass == 2)
    yy_aconf->flags |= GDENY_BLOCK;
}
break;
case 757:
#line 4235 "ircd_parser.y"
	{
  ConfigChannel.cycle_on_hostchange = yylval.number;
}
break;
case 758:
#line 4240 "ircd_parser.y"
	{
  ConfigChannel.disable_fake_channels = yylval.number;
}
break;
case 759:
#line 4245 "ircd_parser.y"
	{
  ConfigChannel.restrict_channels = yylval.number;
}
break;
case 760:
#line 4250 "ircd_parser.y"
	{
  ConfigChannel.disable_local_channels = yylval.number;
}
break;
case 761:
#line 4255 "ircd_parser.y"
	{
  ConfigChannel.use_except = yylval.number;
}
break;
case 762:
#line 4260 "ircd_parser.y"
	{
  ConfigChannel.use_invex = yylval.number;
}
break;
case 763:
#line 4265 "ircd_parser.y"
	{
  ConfigChannel.regex_bans = yylval.number;
}
break;
case 764:
#line 4270 "ircd_parser.y"
	{
  ConfigChannel.use_knock = yylval.number;
}
break;
case 765:
#line 4275 "ircd_parser.y"
	{
  ConfigChannel.use_noctcp = yylval.number;
}
break;
case 766:
#line 4280 "ircd_parser.y"
	{
  ConfigChannel.knock_delay = yystack.l_mark[-1].number;
}
break;
case 767:
#line 4285 "ircd_parser.y"
	{
  ConfigChannel.knock_delay_channel = yystack.l_mark[-1].number;
}
break;
case 768:
#line 4290 "ircd_parser.y"
	{
  ConfigChannel.max_chans_per_user = yystack.l_mark[-1].number;
}
break;
case 769:
#line 4295 "ircd_parser.y"
	{
  ConfigChannel.quiet_on_ban = yylval.number;
}
break;
case 770:
#line 4300 "ircd_parser.y"
	{
  ConfigChannel.max_bans = yystack.l_mark[-1].number;
}
break;
case 771:
#line 4305 "ircd_parser.y"
	{
  ConfigChannel.default_split_user_count = yystack.l_mark[-1].number;
}
break;
case 772:
#line 4310 "ircd_parser.y"
	{
  ConfigChannel.default_split_server_count = yystack.l_mark[-1].number;
}
break;
case 773:
#line 4315 "ircd_parser.y"
	{
  ConfigChannel.no_create_on_split = yylval.number;
}
break;
case 774:
#line 4320 "ircd_parser.y"
	{
  ConfigChannel.no_join_on_split = yylval.number;
}
break;
case 775:
#line 4325 "ircd_parser.y"
	{
  ConfigChannel.burst_topicwho = yylval.number;
}
break;
case 776:
#line 4330 "ircd_parser.y"
	{
  GlobalSetOptions.joinfloodcount = yylval.number;
}
break;
case 777:
#line 4335 "ircd_parser.y"
	{
  GlobalSetOptions.joinfloodtime = yylval.number;
}
break;
case 789:
#line 4354 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.flatten_links = yylval.number;
}
break;
case 790:
#line 4360 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.hide_servers = yylval.number;
}
break;
case 791:
#line 4366 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    MyFree(ConfigServerHide.hidden_name);
    DupString(ConfigServerHide.hidden_name, yylval.string);
  }
}
break;
case 792:
#line 4375 "ircd_parser.y"
	{
  if (ypass == 2)
  {
    if ((yystack.l_mark[-1].number > 0) && ConfigServerHide.links_disabled == 1)
    {
      eventAddIsh("write_links_file", write_links_file, NULL, yystack.l_mark[-1].number);
      ConfigServerHide.links_disabled = 0;
    }

    ConfigServerHide.links_delay = yystack.l_mark[-1].number;
  }
}
break;
case 793:
#line 4389 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.hidden = yylval.number;
}
break;
case 794:
#line 4395 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.disable_hidden = yylval.number;
}
break;
case 795:
#line 4401 "ircd_parser.y"
	{
  if (ypass == 2)
    ConfigServerHide.hide_server_ips = yylval.number;
}
break;
#line 7007 "y.tab.c"
    }
    yystack.s_mark -= yym;
    yystate = *yystack.s_mark;
    yystack.l_mark -= yym;
    yym = yylhs[yyn];
    if (yystate == 0 && yym == 0)
    {
#if YYDEBUG
        if (yydebug)
            printf("%sdebug: after reduction, shifting from state 0 to\
 state %d\n", YYPREFIX, YYFINAL);
#endif
        yystate = YYFINAL;
        *++yystack.s_mark = YYFINAL;
        *++yystack.l_mark = yyval;
        if (yychar < 0)
        {
            if ((yychar = YYLEX) < 0) yychar = 0;
#if YYDEBUG
            if (yydebug)
            {
                yys = 0;
                if (yychar <= YYMAXTOKEN) yys = yyname[yychar];
                if (!yys) yys = "illegal-symbol";
                printf("%sdebug: state %d, reading %d (%s)\n",
                        YYPREFIX, YYFINAL, yychar, yys);
            }
#endif
        }
        if (yychar == 0) goto yyaccept;
        goto yyloop;
    }
    if ((yyn = yygindex[yym]) && (yyn += yystate) >= 0 &&
            yyn <= YYTABLESIZE && yycheck[yyn] == yystate)
        yystate = yytable[yyn];
    else
        yystate = yydgoto[yym];
#if YYDEBUG
    if (yydebug)
        printf("%sdebug: after reduction, shifting from state %d \
to state %d\n", YYPREFIX, *yystack.s_mark, yystate);
#endif
    if (yystack.s_mark >= yystack.s_last && yygrowstack(&yystack))
    {
        goto yyoverflow;
    }
    *++yystack.s_mark = (short) yystate;
    *++yystack.l_mark = yyval;
    goto yyloop;

yyoverflow:
    yyerror("yacc stack overflow");

yyabort:
    yyfreestack(&yystack);
    return (1);

yyaccept:
    yyfreestack(&yystack);
    return (0);
}
